@@ -69,7 +69,7 @@ oleo_set_style (Sheet *sheet, int col, int row, GnmStyle *mstyle)
 		range.start.row = range.end.row = OLEO_TO_GNUMERIC (row);
 
 	/* sheet_style_set_range absorbs our reference */
-	mstyle_ref (mstyle);
+	gnm_style_ref (mstyle);
 	sheet_style_set_range (sheet, &range, mstyle);
 }
 
@@ -154,7 +154,7 @@ oleo_get_gnumeric_expr (char const *o_expr,
 			cellref_as_string (gres, gnm_expr_conventions_default,
 					   &start, cur_pos, TRUE);
 
-			if (!cellref_equal (&start, &end)) {
+			if (!gnm_cellref_equal (&start, &end)) {
 				g_string_append_c (gres, ':');
 				cellref_as_string (gres, gnm_expr_conventions_default,
 						   &end, cur_pos, TRUE);
@@ -295,7 +295,7 @@ oleo_deal_with_format (OleoParseState *state, guint8 *str, int *ccol, int *crow,
 		       GnmStyle **style)
 {
 	char *ptr = str + 1;
-	GnmStyle *mstyle = mstyle_new_default ();
+	GnmStyle *mstyle = gnm_style_new_default ();
 	GString *fmt_string = g_string_new (NULL);
 
 	while (*ptr) {
@@ -322,18 +322,18 @@ oleo_deal_with_format (OleoParseState *state, guint8 *str, int *ccol, int *crow,
 			}
 			break;
 		case 'L':
-			mstyle_set_align_h (mstyle, HALIGN_LEFT);
+			gnm_style_set_align_h (mstyle, HALIGN_LEFT);
 			break;
 		case 'R':
-			mstyle_set_align_h (mstyle, HALIGN_RIGHT);
+			gnm_style_set_align_h (mstyle, HALIGN_RIGHT);
 	}
 	}
 	if (fmt_string->len)
-		mstyle_set_format_text (mstyle, fmt_string->str);
+		gnm_style_set_format_text (mstyle, fmt_string->str);
 	g_string_free (fmt_string, TRUE);
 
 	if (*style)
-		mstyle_unref (*style);
+		gnm_style_unref (*style);
 	*style = mstyle;
 }
 
@@ -356,7 +356,7 @@ oleo_conventions (void)
 	GnmExprConventions *res = gnm_expr_conventions_new ();
 
 	res->decimal_sep_dot = TRUE;
-	res->ref_parser = gnm_1_0_rangeref_parse;
+	res->ref_parser = rangeref_parse;
 	res->range_sep_colon = TRUE;
 	res->sheet_sep_exclamation = TRUE;
 	res->dots_in_names = TRUE;
