@@ -101,6 +101,8 @@ static struct {
 		N_("Simplex algorithm for Solver (LP Solve).") },
 	{ N_("Tom Dyas"),			GNM_FEATURE_HACKER,
 		N_("Original plugin engine.") },
+	{ N_("Kjell Eikland"),            GNM_ANALYTICS,
+	        N_("LP-solve") },
 	{ N_("Gergo Erdi"),			GNM_GUI,
 		N_("Custom UI tools") },
 	{ N_("John Gotts"),			GNM_PACKAGING,
@@ -108,15 +110,13 @@ static struct {
 	{ N_("Andreas J. G\xc3\xbclzow"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
 		N_("Statistics and GUI master") },
 	{ N_("Jon K\xc3\xa5re Hellan"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
-		N_("UI Polish and all round bug fixer") },
+		N_("UI polish and all round bug fixer") },
 	{ N_("Ross Ihaka"),			GNM_ANALYTICS,
 		N_("Special functions") },
 	{ N_("Jukka-Pekka Iivonen"),	GNM_ANALYTICS|GNM_GUI|GNM_FEATURE_HACKER,
 		N_("Solver, lots of worksheet functions, and general trailblazer") },
 	{ N_("Jakub Jel\xc3\xadnek"),		GNM_CORE,
 		N_("One of the original core contributors") },
-	{ N_("Jakub Steiner"),		GNM_ART,
-		N_("Icons and Images") },
 	{ N_("Chris Lahey"),		GNM_FEATURE_HACKER,
 		N_("The original value format engine and libgoffice work") },
 	{ N_("Takashi Matsuda"),		GNM_FEATURE_HACKER,
@@ -127,6 +127,8 @@ static struct {
 		N_("SheetObject improvement") },
 	{ N_("Yukihiro Nakai"),             GNM_FEATURE_HACKER | GNM_TRANSLATION | GNM_QA,
 	        N_("Support for non-Latin languages") },
+	{ N_("Peter Notebaert"),            GNM_ANALYTICS,
+	        N_("LP-solve") },
 	{ N_("Emmanuel Pacaud"),		GNM_CORE | GNM_FEATURE_HACKER,
 		N_("Many plot types for charting engine.") },
 	{ N_("Federico M. Quintero"),	GNM_CORE,
@@ -139,6 +141,8 @@ static struct {
 		N_("original CSV support, French localization") },
 	{ N_("Ariel Rios"),			GNM_SCRIPTING,
 		N_("Guile support") },
+	{ N_("Jakub Steiner"),		GNM_ART,
+		N_("Icons and Images") },
 	{ N_("Uwe Steinmann"),		GNM_FEATURE_HACKER|GNM_IMPORT_EXPORT,
 		N_("Paradox Importer") },
 	{ N_("Arturo Tena"),		GNM_IMPORT_EXPORT,
@@ -169,8 +173,6 @@ cb_plot_resize (FooCanvas *canvas, GtkAllocation *alloc, FooCanvasItem *ctrl)
 	foo_canvas_item_set (ctrl,
 		"w", (double)alloc->width,
 		"h", (double)alloc->height,
-		"logical_width_pts",  ((double)alloc->width)  * 72. / 96.,
-		"logical_height_pts", ((double)alloc->height) * 72. / 96.,
 		NULL);
 }
 static void
@@ -275,6 +277,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 		"state", state, (GDestroyNotify)gnm_about_state_free);
 
 	state->graph = g_object_new (GOG_GRAPH_TYPE, NULL);
+	gog_graph_set_size (GOG_GRAPH (state->graph), 4 * 72.0, 4 * 72.0);
 	GOG_STYLED_OBJECT (state->graph)->style->fill.type = GOG_FILL_STYLE_GRADIENT;
 	GOG_STYLED_OBJECT (state->graph)->style->fill.pattern.back = 0xFFFF99FF;
 	GOG_STYLED_OBJECT (state->graph)->style->fill.gradient.dir = GO_GRADIENT_W_TO_E_MIRRORED;
@@ -318,12 +321,6 @@ dialog_about (WorkbookControlGUI *wbcg)
 	gog_style_set_fill_brightness (
 		GOG_STYLED_OBJECT (series)->style, 70.);
 
-	/* remove the default grid, its ugly here */
-	tmp = gog_object_get_child_by_role (chart,
-		gog_object_find_role_by_name (chart, "Grid"));
-	gog_object_clear_parent (tmp);
-	g_object_unref (tmp);
-
 	/* hide the X-axis */
 	tmp = gog_object_get_child_by_role (chart,
 		gog_object_find_role_by_name (chart, "X-Axis"));
@@ -385,7 +382,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 		pango_font_description_from_string ("Sans Bold 12"));
 
 	state->canvas = foo_canvas_new ();
-	gtk_widget_set_size_request (state->canvas, 450, 400);
+	gtk_widget_set_size_request (state->canvas, 400, 350);
 	foo_canvas_scroll_to (FOO_CANVAS (state->canvas), 0, 0);
 
 	state->ctrl = foo_canvas_item_new (foo_canvas_root (FOO_CANVAS (state->canvas)),
@@ -403,7 +400,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 	g_signal_connect (state->about, "response",
 		G_CALLBACK (gtk_widget_destroy), NULL);
 
-	state->timer = g_timeout_add_full (G_PRIORITY_LOW, 100,
+	state->timer = g_timeout_add_full (G_PRIORITY_LOW, 300,
 					   (GSourceFunc) cb_about_animate, state,
 					   NULL);
 }
