@@ -155,10 +155,12 @@ autocorrect_init_exception_list (AutoCorrectState *state,
 	}
 
 	w = glade_xml_get_widget (state->gui, add_name);
+	gtk_button_set_alignment (GTK_BUTTON (w), 0., .5);
 	g_signal_connect (G_OBJECT (w),
 		"clicked",
 		G_CALLBACK (cb_add_clicked), exception);
 	w = glade_xml_get_widget (state->gui, remove_name);
+	gtk_button_set_alignment (GTK_BUTTON (w), 0., .5);
 	g_signal_connect (G_OBJECT (w),
 		"clicked",
 		G_CALLBACK (cb_remove_clicked), exception);
@@ -316,7 +318,7 @@ dialog_autocorrect (WorkbookControlGUI *wbcg)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, AUTO_CORRECT_KEY))
 		return;
-	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"autocorrect.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -328,7 +330,7 @@ dialog_autocorrect (WorkbookControlGUI *wbcg)
 	state->first_letter.exceptions = NULL;
 
 	if (dialog_init (state)) {
-		gnumeric_notice (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the AutoCorrect dialog."));
 		cb_autocorrect_destroy (NULL, state);
 		return;
