@@ -19,6 +19,7 @@
 #include "dependent.h"
 #include "expr.h"
 #include "expr-impl.h"
+#include "expr-name.h"
 #include "cell.h"
 #include "str.h"
 #include "symbol.h"
@@ -163,6 +164,16 @@ generate_po (void)
 		(GHFunc) cb_generate_po, NULL);
 }
 
+static void
+cb_dump_usage (gpointer key, Symbol *sym, FILE *out)
+{
+	if (sym != NULL) {
+		GnmFunc const *fd = sym->data;
+		if (fd != NULL && fd->ref_count > 0)
+			fprintf (out, "%d,%s\n", fd->ref_count, fd->name);
+	}
+}
+
 /**
  * function_dump_defs :
  * @filename :
@@ -174,6 +185,7 @@ generate_po (void)
  * 0 : 
  * 1 : 
  * 2 :
+ * 3 : dump function usage count
  **/
 void
 function_dump_defs (char const *filename, int dump_type)
@@ -188,7 +200,6 @@ function_dump_defs (char const *filename, int dump_type)
 		generate_po ();
 		return;
 	}
-
 	g_return_if_fail (filename != NULL);
 
 	if ((output_file = g_fopen (filename, "w")) == NULL){
@@ -196,6 +207,13 @@ function_dump_defs (char const *filename, int dump_type)
 		exit (1);
 	}
 
+	if (dump_type == 3) {
+		g_hash_table_foreach (global_symbol_table->hash,
+			(GHFunc) cb_dump_usage, output_file);
+		fclose (output_file);
+		return;
+	}
+
 	/* TODO : Use the translated names and split by fn_group. */
 	ordered = g_ptr_array_new ();
 	g_hash_table_foreach (global_symbol_table->hash,
@@ -965,7 +983,7 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 		if (arg_type == 'A' || arg_type == 'r') {
 			if (expr->any.oper == GNM_EXPR_OP_CELLREF) {
 				GnmCellRef r;
-				cellref_make_abs (&r, &expr->cellref.ref, ei->pos);
+				gnm_cellref_make_abs (&r, &expr->cellref.ref, ei->pos);
 				args[i] = value_new_cellrange_unsafe (&r, &r);
 				/* TODO decide on the semantics of these argument types */
 #warning do we need to force an eval here ?
@@ -973,12 +991,12 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 				tmp = args[i] = gnm_expr_eval (expr, ei->pos,
 					GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
 				if (tmp->type == VALUE_CELLRANGE) {
-					cellref_make_abs (&tmp->v_range.cell.a,
-							  &tmp->v_range.cell.a,
-							  ei->pos);
-					cellref_make_abs (&tmp->v_range.cell.b,
-							  &tmp->v_range.cell.b,
-							  ei->pos);
+					gnm_cellref_make_abs (&tmp->v_range.cell.a,
+						&tmp->v_range.cell.a,
+						ei->pos);
+					gnm_cellref_make_abs (&tmp->v_range.cell.b,
+						&tmp->v_range.cell.b,
+						ei->pos);
 
 				/* Array args accept scalars */
 				} else if (arg_type != 'A' && tmp->type != VALUE_ARRAY) {
@@ -1351,24 +1369,46 @@ function_iterate_do_value (GnmEvalPos const  *ep,
  * GnmValue found on the list (this means that ranges get properly expaned).
  **/
 GnmValue *
-function_iterate_argument_values (GnmEvalPos const		*ep,
+function_iterate_argument_values (GnmEvalPos const	*ep,
 				  FunctionIterateCB	 callback,
 				  void			*callback_closure,
 				  GnmExprList const	*expr_node_list,
 				  gboolean		 strict,
 				  CellIterFlags		 iter_flags)
 {
-	GnmValue * result = NULL;
+	GnmValue *result = NULL;
+	GnmExpr const *expr;
+	GnmValue *val;
 
 	for (; result == NULL && expr_node_list;
 	     expr_node_list = expr_node_list->next) {
-		GnmExpr const *expr = expr_node_list->data;
-		GnmValue *val;
+		expr = expr_node_list->data;
 
 		if (iter_flags & CELL_ITER_IGNORE_SUBTOTAL &&
 		    gnm_expr_containts_subtotal (expr))
 			continue;
 
+/* NOT UNTIL 1.7 */
+#if 0
+		/* need to drill down into names to handle things like
+		 * sum(name)  with name := (A:A,B:B) */
+		while (expr->any.oper == GNM_EXPR_OP_NAME) {
+			expr = expr->name.name->expr;
+			if (expr == NULL) {
+				if (strict)
+					return value_new_error_REF (ep);
+				continue;
+			}
+		}
+
+		/* Handle sets as a special case */
+		if (expr->any.oper == GNM_EXPR_OP_SET) {
+			result = function_iterate_argument_values (ep, callback,
+				callback_closure, expr->set.set, strict, iter_flags);
+			continue;
+		}
+#endif
+
 		/* Permit empties and non scalars. We don't know what form the
 		 * function wants its arguments */
 		val = gnm_expr_eval (expr, ep, GNM_EXPR_EVAL_PERMIT_NON_SCALAR|GNM_EXPR_EVAL_PERMIT_EMPTY);
