@@ -230,6 +230,15 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 
 	case GDK_KP_Delete:
 	case GDK_Delete:
+		if (wbcg_is_editing (wbcg)) {
+			/* stop auto-completion. then do a quick and cheesy update */
+			wbcg_auto_complete_destroy (wbcg);
+			SCG_FOREACH_PANE (scg, pane, {
+				if (pane->editor)
+					foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor));
+			});
+			return TRUE;
+		}
 		if (gnm_canvas_guru_key (wbcg, event))
 			break;
 		if (state == GDK_SHIFT_MASK) {
@@ -290,6 +299,14 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 		if (gnm_canvas_guru_key (wbcg, event))
 			break;
 
+		if (wbcg_is_editing (wbcg)) {
+			GtkWidget *entry = (GtkWidget *) wbcg_get_entry (wbcg);
+			GtkWindow *top   = wbcg_toplevel (wbcg);
+			if (entry != gtk_window_get_focus (top)) {
+				gtk_window_set_focus (top, entry);
+				return TRUE;
+			}
+		}
 		if (!wbcg_edit_start (wbcg, FALSE, FALSE))
 			return FALSE; /* attempt to edit failed */
 		/* fall down */
@@ -420,25 +437,25 @@ gnm_canvas_key_press (GtkWidget *widget, GdkEventKey *event)
 	SheetControlGUI *scg = gcanvas->simple.scg;
 	gboolean res;
 
-	if (scg->grab_stack > 0)
-		return TRUE;
-
 	if (wbcg_edit_get_guru (scg->wbcg) == NULL  &&
 	    (scg->selected_objects != NULL || scg->new_object != NULL))
 		res = gnm_canvas_key_mode_object (gcanvas, event);
 	else {
+		if (scg->grab_stack > 0)
+			return TRUE;
+
 		gcanvas->mask_state = event->state;
-		if (gtk_im_context_filter_keypress (gcanvas->im_context,event)) {
-			gcanvas->need_im_reset = TRUE;
+		if (gtk_im_context_filter_keypress (gcanvas->im_context,event))
 			return TRUE;
-		}
 		switch (event->keyval) {
 		case GDK_Shift_L:   case GDK_Shift_R:
 		case GDK_Alt_L:     case GDK_Alt_R:
 		case GDK_Control_L: case GDK_Control_R:
 			break;
 		default:
+			gcanvas->reseting_im = TRUE;
 			gtk_im_context_reset (gcanvas->im_context);
+			gcanvas->reseting_im = FALSE;
 			break;
 		}
 		res = gnm_canvas_key_mode_sheet (gcanvas, event);
@@ -467,10 +484,7 @@ gnm_canvas_key_release (GtkWidget *widget, GdkEventKey *event)
 		return TRUE;
 
 	if (gtk_im_context_filter_keypress (gcanvas->im_context,event))
-	{
-		gcanvas->need_im_reset = TRUE;
 		return TRUE;
-	}
 	/*
 	 * The status_region normally displays the current edit_pos
 	 * When we extend the selection it changes to displaying the size of
@@ -486,20 +500,16 @@ gnm_canvas_key_release (GtkWidget *widget, GdkEventKey *event)
 	return (*GTK_WIDGET_CLASS (parent_klass)->key_release_event) (widget, event);
 }
 
-/* Focus in handler for the canvas */
 static gint
 gnm_canvas_focus_in (GtkWidget *widget, GdkEventFocus *event)
 {
-	GNM_CANVAS (widget)->need_im_reset = TRUE;
 	gtk_im_context_focus_in (GNM_CANVAS (widget)->im_context);
 	return (*GTK_WIDGET_CLASS (parent_klass)->focus_in_event) (widget, event);
 }
 
-/* Focus out handler for the canvas */
 static gint
 gnm_canvas_focus_out (GtkWidget *widget, GdkEventFocus *event)
 {
-	GNM_CANVAS (widget)->need_im_reset = TRUE;
 	gtk_im_context_focus_out (GNM_CANVAS (widget)->im_context);
 	return (*GTK_WIDGET_CLASS (parent_klass)->focus_out_event) (widget, event);
 }
@@ -618,11 +628,15 @@ gnm_canvas_preedit_changed_cb (GtkIMContext *context, GnmCanvas *gcanvas)
 		pango_attr_list_unref (gcanvas->preedit_attrs);
 	gtk_im_context_get_preedit_string (gcanvas->im_context, &preedit_string, &gcanvas->preedit_attrs, &cursor_pos);
 
-	if (!wbcg_is_editing (wbcg) && !wbcg_edit_start (wbcg, TRUE, TRUE)) {
+	/* in gtk-2.8 something changed.  gtk_im_context_reset started
+	 * triggering a pre-edit-changed.  We'd end up start and finishing an
+	 * empty edit every time the cursor moved */
+	if (!gcanvas->reseting_im &&
+	    !wbcg_is_editing (wbcg) && !wbcg_edit_start (wbcg, TRUE, TRUE)) {
 		gtk_im_context_reset (gcanvas->im_context);
 		gcanvas->preedit_length = 0;
 		if (gcanvas->preedit_attrs)
-				pango_attr_list_unref (gcanvas->preedit_attrs);
+			pango_attr_list_unref (gcanvas->preedit_attrs);
 		gcanvas->preedit_attrs = NULL;
 		g_free (preedit_string);
 		return;
@@ -690,6 +704,7 @@ gnm_canvas_init (GnmCanvas *gcanvas)
 	gcanvas->im_context = gtk_im_multicontext_new ();
 	gcanvas->preedit_length = 0;
 	gcanvas->preedit_attrs = NULL;
+	gcanvas->reseting_im = FALSE;
 
 	g_signal_connect (G_OBJECT (gcanvas->im_context), "commit",
 		G_CALLBACK (gnm_canvas_commit_cb), gcanvas);
@@ -1051,9 +1066,8 @@ row_scroll_step (int dy)
 }
 
 static gint
-gcanvas_sliding_callback (gpointer data)
+cb_gcanvas_sliding (GnmCanvas *gcanvas)
 {
-	GnmCanvas *gcanvas = data;
 	int const pane_index = gcanvas->pane->index;
 	GnmCanvas *gcanvas0 = scg_pane (gcanvas->simple.scg, 0);
 	GnmCanvas *gcanvas1 = scg_pane (gcanvas->simple.scg, 1);
@@ -1061,6 +1075,7 @@ gcanvas_sliding_callback (gpointer data)
 	gboolean slide_x = FALSE, slide_y = FALSE;
 	int col = -1, row = -1;
 	gboolean text_is_rtl = gcanvas->simple.scg->sheet_control.sheet->text_is_rtl;
+	GnmCanvasSlideInfo info;
 
 #if 0
 	g_warning ("slide: %d, %d", gcanvas->sliding_dx, gcanvas->sliding_dy);
@@ -1187,16 +1202,18 @@ gcanvas_sliding_callback (gpointer data)
 	} else if (row < 0)
 		row = gnm_canvas_find_row (gcanvas, gcanvas->sliding_y, NULL);
 
+	info.col = col;
+	info.row = row;
+	info.user_data = gcanvas->slide_data;
 	if (gcanvas->slide_handler == NULL ||
-	    (*gcanvas->slide_handler) (gcanvas, col, row, gcanvas->slide_data))
+	    (*gcanvas->slide_handler) (gcanvas, &info))
 		scg_make_cell_visible (gcanvas->simple.scg, col, row, FALSE, TRUE);
 
-	if (slide_x || slide_y) {
-		if (gcanvas->sliding == -1)
-			gcanvas->sliding = g_timeout_add (
-				300, gcanvas_sliding_callback, gcanvas);
-	} else
+	if (!slide_x && !slide_y)
 		gnm_canvas_slide_stop (gcanvas);
+	else if (gcanvas->sliding == -1)
+		gcanvas->sliding = g_timeout_add (
+			300, (GSourceFunc) cb_gcanvas_sliding, gcanvas);
 
 	return TRUE;
 }
@@ -1335,11 +1352,13 @@ gnm_canvas_handle_motion (GnmCanvas *gcanvas,
 	/* Movement is inside the visible region */
 	if (dx == 0 && dy == 0) {
 		if (!(slide_flags & GNM_CANVAS_SLIDE_EXTERIOR_ONLY)) {
-			int const row = gnm_canvas_find_row (gcanvas, y, NULL);
-			int const col = gnm_canvas_find_col (gcanvas, text_is_rtl
-				? -(x + gcanvas->simple.canvas.scroll_x1 * gcanvas->simple.canvas.pixels_per_unit) : x, NULL);
-
-			(*slide_handler) (gcanvas, col, row, user_data);
+			GnmCanvasSlideInfo info;
+			info.row = gnm_canvas_find_row (gcanvas, y, NULL);
+			info.col = gnm_canvas_find_col (gcanvas, text_is_rtl
+				? -(x + gcanvas->simple.canvas.scroll_x1 * gcanvas->simple.canvas.pixels_per_unit)
+				: x, NULL);
+			info.user_data = user_data;;
+			(*slide_handler) (gcanvas, &info);
 		}
 		gnm_canvas_slide_stop (gcanvas);
 		return TRUE;
@@ -1353,7 +1372,7 @@ gnm_canvas_handle_motion (GnmCanvas *gcanvas,
 	gcanvas->slide_data = user_data;
 
 	if (gcanvas->sliding == -1)
-		(void) gcanvas_sliding_callback (gcanvas);
+		cb_gcanvas_sliding (gcanvas);
 	return FALSE;
 }
 
@@ -1381,3 +1400,111 @@ gnm_canvas_slide_init (GnmCanvas *gcanvas)
 		? (gcanvas3->last_full.row == (gcanvas0->first.row - 1))
 		: FALSE;
 }
+
+/*
+ * gnm_canvas_window_to_coord :
+ * @gcanvas : #GnmCanvas
+ * @x :
+ * @y :
+ * @wx : result
+ * @wy : result
+ * 
+ * Map window coords into sheet object coords
+ **/
+void
+gnm_canvas_window_to_coord (GnmCanvas *gcanvas,
+			    gint    x,	gint    y,
+			    double *wx, double *wy)
+{
+	double const scale = 1. / FOO_CANVAS (gcanvas)->pixels_per_unit;
+	y += gcanvas->first_offset.row;
+
+	if (gcanvas->simple.scg->sheet_control.sheet->text_is_rtl)
+		x = x - GTK_WIDGET (gcanvas)->allocation.width - gcanvas->first_offset.col;
+	else
+		x += gcanvas->first_offset.col;
+	*wx = x * scale;
+	*wy = y * scale;
+}
+
+static gboolean
+cb_obj_autoscroll (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
+{
+	SheetControlGUI *scg = gcanvas->simple.scg;
+	GdkModifierType mask;
+
+	/* Cheesy hack calculate distance we move the screen, this loses the
+	 * mouse position */
+	double dx = gcanvas->first_offset.col;
+	double dy = gcanvas->first_offset.row;
+	scg_make_cell_visible (scg, info->col, info->row, FALSE, TRUE);
+	dx = gcanvas->first_offset.col - dx;
+	dy = gcanvas->first_offset.row - dy;
+
+#if 0
+	g_warning ("dx = %g, dy = %g", dx, dy);
+#endif
+
+	gcanvas->pane->drag.had_motion = TRUE;
+	gdk_window_get_pointer (gtk_widget_get_parent_window (GTK_WIDGET (gcanvas)),
+		NULL, NULL, &mask);
+ 	scg_objects_drag (gcanvas->simple.scg, gcanvas,
+ 		NULL, &dx, &dy, 8, FALSE, (mask & GDK_SHIFT_MASK) != 0, TRUE);
+
+ 	gcanvas->pane->drag.last_x += dx;
+ 	gcanvas->pane->drag.last_y += dy;
+	return FALSE;
+}
+
+/**
+ * This does not really belong here.  We're breaking all sorts of encapsulations
+ * but the line between GnmCanvas and GnmPane is blurry.
+ **/
+void
+gnm_canvas_object_autoscroll (GnmCanvas *gcanvas, GdkDragContext *context,
+			      gint x, gint y, guint time)
+{
+	int const pane_index = gcanvas->pane->index;
+	SheetControlGUI *scg = gcanvas->simple.scg;
+	GnmCanvas *gcanvas0 = scg_pane (scg, 0);
+	GnmCanvas *gcanvas1 = scg_pane (scg, 1);
+	GnmCanvas *gcanvas3 = scg_pane (scg, 3);
+	GtkWidget *w = GTK_WIDGET (gcanvas);
+	gint dx, dy;
+
+	if (y < w->allocation.y) {
+		if (pane_index < 2 && gcanvas3 != NULL)
+			w = GTK_WIDGET (gcanvas3);
+		dy = y - w->allocation.y;
+		g_return_if_fail (dy <= 0);
+	} else if (y >= (w->allocation.y + w->allocation.height)) {
+		if (pane_index >= 2)
+			w = GTK_WIDGET (gcanvas0);
+		dy = y - (w->allocation.y + w->allocation.height);
+		g_return_if_fail (dy >= 0);
+	} else
+		dy = 0;
+	if (x < w->allocation.x) {
+		if ((pane_index == 0 || pane_index == 3) && gcanvas1 != NULL)
+			w = GTK_WIDGET (gcanvas1);
+		dx = x - w->allocation.x;
+		g_return_if_fail (dx <= 0);
+	} else if (x >= (w->allocation.x + w->allocation.width)) {
+		if (pane_index >= 2)
+			w = GTK_WIDGET (gcanvas0);
+		dx = x - (w->allocation.x + w->allocation.width);
+		g_return_if_fail (dx >= 0);
+	} else
+		dx = 0;
+
+	g_object_set_data (&context->parent_instance,
+		"wbcg", scg_get_wbcg (scg));
+	gcanvas->sliding_dx    = dx;
+	gcanvas->sliding_dy    = dy;
+	gcanvas->slide_handler = &cb_obj_autoscroll;
+	gcanvas->slide_data    = NULL;
+	gcanvas->sliding_x     = x;
+	gcanvas->sliding_y     = y;
+	if (gcanvas->sliding == -1)
+		cb_gcanvas_sliding (gcanvas);
+}
