@@ -46,6 +46,7 @@ struct _ItemCursor {
 	FooCanvasItem canvas_item;
 
 	SheetControlGUI *scg;
+	gboolean	 pos_initialized;
 	GnmRange		 pos;
 
 	/* Offset of dragging cell from top left of pos */
@@ -69,8 +70,9 @@ struct _ItemCursor {
 	GnmRange autofill_src;
 	int   autofill_hsize, autofill_vsize;
 
-	/* Cached values of the last bounding box information used */
-	int      cached_x, cached_y, cached_w, cached_h;
+	struct { /* cursor outline in canvas coords (bounding box is larger) */
+		int x1, x2, y1, y2;
+	} outline;
 	int	 drag_button;
 
 	gboolean visible;
@@ -137,15 +139,9 @@ item_cursor_realize (FooCanvasItem *item)
 			ic);
 	}
 
-	/*
-	 * Create the stipple pattern for the drag and the autofill cursors
-	 */
-	if (ic->style == ITEM_CURSOR_DRAG ||
-	    ic->style == ITEM_CURSOR_AUTOFILL) {
-		static char stipple_data [] = { 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa };
-
-		ic->stipple =
-			gdk_bitmap_create_from_data (window, stipple_data, 8, 8);
+	if (ic->style == ITEM_CURSOR_DRAG || ic->style == ITEM_CURSOR_AUTOFILL) {
+		static char const stipple_data [] = { 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa };
+		ic->stipple = gdk_bitmap_create_from_data (window, stipple_data, 8, 8);
 	}
 }
 
@@ -174,29 +170,13 @@ item_cursor_unrealize (FooCanvasItem *item)
 		(*parent_class->unrealize) (item);
 }
 
-static void
-item_cursor_request_redraw (ItemCursor *ic)
-{
-	FooCanvas *canvas = FOO_CANVAS_ITEM (ic)->canvas;
-	int const x = ic->cached_x;
-	int const y = ic->cached_y;
-	int const w = ic->cached_w;
-	int const h = ic->cached_h;
-
-	foo_canvas_request_redraw (canvas, x - 2, y - 2, x + 2, y + h + 2);
-	foo_canvas_request_redraw (canvas, x - 2, y - 2, x + w + 2, y + 2);
-	foo_canvas_request_redraw (canvas, x + w - 2, y - 2, x + w + 5, y + h + 5);
-	foo_canvas_request_redraw (canvas, x - 2, y + h - 2, x + w + 5, y + h + 5);
-}
-
 static void
 item_cursor_update (FooCanvasItem *item, double i2w_dx, double i2w_dy, int flags)
 {
 	ItemCursor    *ic = ITEM_CURSOR (item);
 	GnmCanvas *gcanvas = GNM_CANVAS (item->canvas);
 	SheetControlGUI const * const scg = ic->scg;
-
-	int x, y, w, h, extra;
+	int tmp;
 
 	/* Clip the bounds of the cursor to the visible region of cells */
 	int const left = MAX (gcanvas->first.col-1, ic->pos.start.col);
@@ -204,44 +184,43 @@ item_cursor_update (FooCanvasItem *item, double i2w_dx, double i2w_dy, int flags
 	int const top = MAX (gcanvas->first.row-1, ic->pos.start.row);
 	int const bottom = MIN (gcanvas->last_visible.row+1, ic->pos.end.row);
 
-	/* Erase the old cursor */
-	item_cursor_request_redraw (ic);
+	foo_canvas_item_request_redraw (item); /* Erase the old cursor */
 
-	ic->cached_x = x =
-		gcanvas->first_offset.col +
+	ic->outline.x1 = gcanvas->first_offset.col +
 		scg_colrow_distance_get (scg, TRUE, gcanvas->first.col, left);
-	ic->cached_y = y =
-		gcanvas->first_offset.row +
+	ic->outline.x2 = ic->outline.x1 +
+		scg_colrow_distance_get (scg, TRUE, left, right+1);
+	ic->outline.y1 = gcanvas->first_offset.row +
 		scg_colrow_distance_get (scg, FALSE, gcanvas->first.row, top);
-	ic->cached_w = w = scg_colrow_distance_get (scg, TRUE, left, right+1);
-	ic->cached_h = h = scg_colrow_distance_get (scg, FALSE,top, bottom+1);
+	ic->outline.y2 = ic->outline.y1 +
+		scg_colrow_distance_get (scg, FALSE,top, bottom+1);
 
-	item->x1 = x - 1;
-	item->y1 = y - 1;
+	if (scg->sheet_control.sheet->text_is_rtl) {
+		tmp = ic->outline.x1;
+		ic->outline.x1 = gnm_simple_canvas_x_w2c (item->canvas, ic->outline.x2);
+		ic->outline.x2 = gnm_simple_canvas_x_w2c (item->canvas, tmp);
+	}
+	/* NOTE : sometimes y1 > y2 || x1 > x2 when we create a cursor in an
+	 * invisible region such as above a frozen pane */
+
+	item->x1 = ic->outline.x1 - 1;
+	item->y1 = ic->outline.y1 - 1;
 
 	/* for the autohandle */
-	extra = (ic->style == ITEM_CURSOR_SELECTION) ? AUTO_HANDLE_WIDTH : 0;
+	tmp = (ic->style == ITEM_CURSOR_SELECTION) ? AUTO_HANDLE_WIDTH : 0;
+	item->x2 = ic->outline.x2 + 3 + tmp;
+	item->y2 = ic->outline.y2 + 3 + tmp;
 
-	item->x2 = x + w + 3 + extra;
-	item->y2 = y + h + 3 + extra;
+	foo_canvas_item_request_redraw (item); /* draw the new cursor */
 
-	/* Draw the new cursor */
-	item_cursor_request_redraw (ic);
-
-#if 0
-	fprintf (stderr, "update %d,%d %d,%d\n", x, y, w,h);
-#endif
 	if (parent_class->update)
 		(*parent_class->update) (item, i2w_dx, i2w_dy, flags);
 }
 
 /*
- * item_cursor_draw
- *
  * Draw an item of this type.  (x, y) are the upper-left canvas pixel
  * coordinates of the drawable, a temporary pixmap, where things get
  * drawn.  (width, height) are the dimensions of the drawable.
- *
  * In other words - a clipping region.
  */
 static void
@@ -250,29 +229,32 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 {
 	GdkGCValues values;
 	ItemCursor *ic = ITEM_CURSOR (item);
-	int dx0, dy0, dx1, dy1;
+	int x0, y0, x1, y1; /* in canvas coordinates */
 	GdkPoint points [5];
 	int draw_thick, draw_handle;
 	int premove = 0;
 	GdkColor *fore = NULL, *back = NULL;
 	gboolean draw_stippled, draw_center, draw_external, draw_internal;
 
-	int const xd = ic->cached_x;
-	int const yd = ic->cached_y;
-	int const w = ic->cached_w;
-	int const h = ic->cached_h;
-
 #if 0
-	fprintf (stderr, "draw %d,%d %d,%d\n", xd, yd, w,h);
+	fprintf (stderr, "draw[%d] %d,%d %d,%d\n",
+		 GNM_CANVAS (item->canvas)->pane->index, 
+		 ic->outline.x1,
+		 ic->outline.y1,
+		 ic->outline.x2,
+		 ic->outline.y2);
 #endif
-	if (!ic->visible)
+	if (!ic->visible || !ic->pos_initialized)
 		return;
 
-	/* Top left and bottom right corner of cursor, in pixmap coordinates */
-	dx0 = xd;
-	dy0 = yd;
-	dx1 = dx0 + w;
-	dy1 = dy0 + h;
+	x0 = ic->outline.x1;
+	y0 = ic->outline.y1;
+	x1 = ic->outline.x2;
+	y1 = ic->outline.y2;
+
+	/* only mostly in invisible areas (eg on creation of frozen panes) */
+	if (x0 > x1 || y0 > y1)
+		return;
 
 	draw_external = FALSE;
 	draw_internal = FALSE;
@@ -346,10 +328,10 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	 * the shape we draw, so long as no lines or parts of
 	 * rectangles are moved from outside to inside the clipping
 	 * region */
-	dx0 = MAX (dx0, expose->area.x - CLIP_SAFETY_MARGIN);
-	dy0 = MAX (dy0, expose->area.y - CLIP_SAFETY_MARGIN);
-	dx1 = MIN (dx1, expose->area.x + expose->area.width + CLIP_SAFETY_MARGIN);
-	dy1 = MIN (dy1, expose->area.y + expose->area.height + CLIP_SAFETY_MARGIN);
+	x0 = MAX (x0, expose->area.x - CLIP_SAFETY_MARGIN);
+	y0 = MAX (y0, expose->area.y - CLIP_SAFETY_MARGIN);
+	x1 = MIN (x1, expose->area.x + expose->area.width + CLIP_SAFETY_MARGIN);
+	y1 = MIN (y1, expose->area.y + expose->area.height + CLIP_SAFETY_MARGIN);
 
 	gdk_gc_set_line_attributes (ic->gc, 1,
 		GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
@@ -367,15 +349,15 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 		/* No auto handle */
 		case 0 :
-			points [0].x = dx1 + 1;
-			points [0].y = dy1 + 1 - premove;
+			points [0].x = x1 + 1;
+			points [0].y = y1 + 1 - premove;
 			points [1].x = points [0].x;
-			points [1].y = dy0 - 1;
-			points [2].x = dx0 - 1;
-			points [2].y = dy0 - 1;
-			points [3].x = dx0 - 1;
-			points [3].y = dy1 + 1;
-			points [4].x = dx1 + 1 - premove;
+			points [1].y = y0 - 1;
+			points [2].x = x0 - 1;
+			points [2].y = y0 - 1;
+			points [3].x = x0 - 1;
+			points [3].y = y1 + 1;
+			points [4].x = x1 + 1 - premove;
 			points [4].y = points [3].y;
 			break;
 
@@ -385,15 +367,15 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 		/* Auto handle at top of sheet */
 		case 3 :
-			points [0].x = dx1 + 1;
-			points [0].y = dy0 - 1 + AUTO_HANDLE_SPACE;
+			points [0].x = x1 + 1;
+			points [0].y = y0 - 1 + AUTO_HANDLE_SPACE;
 			points [1].x = points [0].x;
-			points [1].y = dy1 + 1;
-			points [2].x = dx0 - 1;
+			points [1].y = y1 + 1;
+			points [2].x = x0 - 1;
 			points [2].y = points [1].y;
 			points [3].x = points [2].x;
-			points [3].y = dy0 - 1;
-			points [4].x = dx1 + 1 - premove;
+			points [3].y = y0 - 1;
+			points [4].x = x1 + 1 - premove;
 			points [4].y = points [3].y;
 			break;
 
@@ -427,31 +409,31 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	}
 
 	if (draw_handle == 1 || draw_handle == 2) {
-		int const y_off = (draw_handle == 1) ? dy1 - dy0 : 0;
+		int const y_off = (draw_handle == 1) ? y1 - y0 : 0;
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 - 2,
-				    dy0 + y_off - 2,
+				    x1 - 2,
+				    y0 + y_off - 2,
 				    2, 2);
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 + 1,
-				    dy0 + y_off - 2,
+				    x1 + 1,
+				    y0 + y_off - 2,
 				    2, 2);
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 - 2,
-				    dy0 + y_off + 1,
+				    x1 - 2,
+				    y0 + y_off + 1,
 				    2, 2);
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 + 1,
-				    dy0 + y_off + 1,
+				    x1 + 1,
+				    y0 + y_off + 1,
 				    2, 2);
 	} else if (draw_handle == 3) {
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 - 2,
-				    dy0 + 1,
+				    x1 - 2,
+				    y0 + 1,
 				    2, 4);
 		gdk_draw_rectangle (drawable, ic->gc, TRUE,
-				    dx1 + 1,
-				    dy0 + 1,
+				    x1 + 1,
+				    y0 + 1,
 				    2, 4);
 	}
 
@@ -470,12 +452,12 @@ item_cursor_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 		/* Stay in the boundary */
 		if ((draw_thick % 2) == 0) {
-			dx0++;
-			dy0++;
+			x0++;
+			y0++;
 		}
 		gdk_draw_rectangle (drawable, ic->gc, FALSE,
-				    dx0, dy0,
-				    abs (dx1 - dx0), abs (dy1 - dy0));
+				    x0, y0,
+				    abs (x1 - x0), abs (y1 - y0));
 	}
 }
 
@@ -485,10 +467,11 @@ item_cursor_bound_set (ItemCursor *ic, GnmRange const *new_bound)
 	g_return_val_if_fail (IS_ITEM_CURSOR (ic), FALSE);
 	g_return_val_if_fail (range_is_sane (new_bound), FALSE);
 
-	if (range_equal (&ic->pos, new_bound))
+	if (range_equal (&ic->pos, new_bound) && ic->pos_initialized)
 		return FALSE;
 
 	ic->pos = *new_bound;
+	ic->pos_initialized = TRUE;
 
 	foo_canvas_item_request_update (FOO_CANVAS_ITEM (ic));
 
@@ -912,12 +895,12 @@ item_cursor_target_region_ok (ItemCursor *ic)
 	if (sv_is_region_empty_or_selected (sc->view, &ic->pos))
 		return TRUE;
 
-	return gnumeric_dialog_question_yes_no
+	return go_gtk_query_yes_no
 		(wbcg_toplevel (ic->scg->wbcg),
+		 TRUE,
 		 _("The cells dragged will overwrite the contents of the\n"
 		   "existing cells in that range.  Do you want me to replace\n"
-		   "the contents in this region?"),
-		 TRUE);
+		   "the contents in this region?"));
 }
 
 typedef enum {
@@ -1126,20 +1109,20 @@ item_cursor_tip_setlabel (ItemCursor *ic)
 }
 
 static gboolean
-cb_move_cursor (GnmCanvas *gcanvas, int col, int row, gpointer user_data)
+cb_move_cursor (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
 {
-	ItemCursor *ic = user_data;
+	ItemCursor *ic = info->user_data;
 	int const w = (ic->pos.end.col - ic->pos.start.col);
 	int const h = (ic->pos.end.row - ic->pos.start.row);
 	GnmCellPos corner;
 
-	corner.col = col - ic->col_delta;
+	corner.col = info->col - ic->col_delta;
 	if (corner.col < 0)
 		corner.col = 0;
 	else if (corner.col >= (SHEET_MAX_COLS - w))
 		corner.col = SHEET_MAX_COLS - w - 1;
 
-	corner.row = row - ic->row_delta;
+	corner.row = info->row - ic->row_delta;
 	if (corner.row < 0)
 		corner.row = 0;
 	else if (corner.row >= (SHEET_MAX_ROWS - h))
@@ -1148,8 +1131,8 @@ cb_move_cursor (GnmCanvas *gcanvas, int col, int row, gpointer user_data)
 	item_cursor_tip_setlabel (ic);
 
 	/* Make target cell visible, and adjust the cursor size */
-	item_cursor_set_bounds_visibly (ic, col, row, &corner,
-					corner.col + w, corner.row + h);
+	item_cursor_set_bounds_visibly (ic, info->col, info->row, &corner,
+		corner.col + w, corner.row + h);
 	return FALSE;
 }
 
@@ -1198,14 +1181,14 @@ item_cursor_drag_event (FooCanvasItem *item, GdkEvent *event)
 }
 
 static gboolean
-cb_autofill_scroll (GnmCanvas *gcanvas, int col, int row, gpointer user_data)
+cb_autofill_scroll (GnmCanvas *gcanvas, GnmCanvasSlideInfo const *info)
 {
-	ItemCursor *ic = user_data;
+	ItemCursor *ic = info->user_data;
 	GnmRange r = ic->autofill_src;
+	int col = info->col, row = info->row;
 
 	/* compass offsets are distances (in cells) from the edges of the
-	 * selected area to the mouse cursor
-	 */
+	 * selected area to the mouse cursor */
 	int north_offset = r.start.row - row;
 	int south_offset = row - r.end.row;
 	int west_offset  = r.start.col - col;
@@ -1356,19 +1339,23 @@ item_cursor_class_init (GObjectClass *gobject_klass)
 	g_object_class_install_property (gobject_klass, ITEM_CURSOR_PROP_SHEET_CONTROL_GUI,
 		g_param_spec_object ("SheetControlGUI", "SheetControlGUI",
 			"the sheet control gui controlling the item",
-			SHEET_CONTROL_GUI_TYPE, G_PARAM_WRITABLE));
+			SHEET_CONTROL_GUI_TYPE,
+			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, ITEM_CURSOR_PROP_STYLE,
 		g_param_spec_int ("style", "Style",
 			"What type of cursor",
-			0, G_MAXINT, 0, G_PARAM_WRITABLE));
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, ITEM_CURSOR_PROP_BUTTON,
 		g_param_spec_int ("button", "Button",
 			"what button initiated the drag",
-			0, G_MAXINT, 0, G_PARAM_WRITABLE));
+			0, G_MAXINT, 0,
+                        GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, ITEM_CURSOR_PROP_COLOR,
 		g_param_spec_string ("color", "Color",
 			"name of the cursor's color",
-			"black", G_PARAM_WRITABLE));
+			"black",
+                        GSF_PARAM_STATIC |  G_PARAM_WRITABLE));
 
 	item_klass->update      = item_cursor_update;
 	item_klass->realize     = item_cursor_realize;
@@ -1388,6 +1375,7 @@ item_cursor_init (ItemCursor *ic)
 	item->x2 = 1;
 	item->y2 = 1;
 
+	ic->pos_initialized = FALSE;
 	ic->pos.start.col = 0;
 	ic->pos.end.col   = 0;
 	ic->pos.start.row = 0;
