@@ -53,6 +53,7 @@ static char *func_def_file = NULL;
 static char *func_state_file = NULL;
 
 int gnumeric_no_splash = FALSE;
+int gnumeric_no_warnings = FALSE;
 
 static struct poptOption
 gnumeric_popt_options[] = {
@@ -86,6 +87,8 @@ gnumeric_popt_options[] = {
 
 	{ "no-splash", '\0', POPT_ARG_NONE, &gnumeric_no_splash, 0,
 	  N_("Don't show splash screen"), NULL },
+	{ "no-warnings", '\0', POPT_ARG_NONE, &gnumeric_no_warnings, 0,
+	  N_("Don't display warning dialogs when importing"), NULL },
 
 	{ "quit", '\0', POPT_ARG_NONE, &immediate_exit_flag, 0,
 	  N_("Exit immediately after loading the selected books (useful for testing)."), NULL },
@@ -144,6 +147,8 @@ warn_about_ancient_gnumerics (const char *binary, IOContext *ioc)
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-init.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnomeui/gnome-authentication-manager.h>
+#include <libgnomevfs/gnome-vfs-init.h>
 
 static GnomeProgram *program;
 
@@ -174,6 +179,10 @@ gnumeric_arg_parse (int argc, char const *argv [])
 		GNOME_PARAM_APP_LIBDIR,		gnm_sys_lib_dir (),
 		GNOME_PARAM_POPT_TABLE,		gnumeric_popt_options,
 		NULL);
+	if (i == argc) {		/* Has gui */
+		gnome_vfs_init ();
+		gnome_authentication_manager_init ();
+	}
 
 	g_object_get (G_OBJECT (program),
 		GNOME_PARAM_POPT_CONTEXT,	&ctx,
@@ -239,7 +248,8 @@ gnumeric_arg_parse (int argc, char const *argv [])
 	gnumeric_popt_options[8].arg = &print_debugging;
 	gnumeric_popt_options[9].arg = &x_geometry;
 	gnumeric_popt_options[10].arg = &gnumeric_no_splash;
-	gnumeric_popt_options[11].arg = &immediate_exit_flag;
+	gnumeric_popt_options[11].arg = &gnumeric_no_warnings;
+	gnumeric_popt_options[12].arg = &immediate_exit_flag;
 #endif
 
 	/* no need to init gtk when dumping function info */
@@ -279,6 +289,39 @@ cb_kill_wbcg (WorkbookControlGUI *wbcg)
 	return FALSE;
 }
 
+static void
+check_pango_attr_list_splice_bug (void)
+{
+	PangoAttrList *l1 = pango_attr_list_new ();
+	PangoAttrList *l2 = pango_attr_list_new ();
+	PangoAttribute *a = pango_attr_weight_new (1000);
+	PangoAttrIterator *it;
+	gboolean buggy;
+
+	a->start_index = 4;
+	a->end_index = 5;
+	pango_attr_list_insert (l1, a);
+
+	pango_attr_list_splice (l1, l2, 0, 1);
+	pango_attr_list_unref (l2);
+
+	it = pango_attr_list_get_iterator (l1);
+	if (pango_attr_iterator_next (it)) {
+		gint s, e;
+		pango_attr_iterator_range (it, &s, &e);
+		buggy = (s != 5 || e != 6);
+	} else
+		buggy = TRUE;
+	pango_attr_iterator_destroy (it);
+	pango_attr_list_unref (l1);
+
+	if (buggy)
+		g_warning (_("The Pango library present on your system is buggy, see\n"
+			     "http://bugzilla.gnome.org/show_bug.cgi?id=316054\n"
+			     "Editing rich text therefore does not work well.  Please check\n"
+			     "with your distribution if a fixed Pango library is available."));
+}
+
 int
 main (int argc, char const *argv [])
 {
@@ -289,14 +332,12 @@ main (int argc, char const *argv [])
 	WorkbookView *wbv;
 	GSList *wbcgs_to_kill = NULL;
 	poptContext ctx;
-	gchar **args;
-	
-	args = go_shell_argv_to_glib_encoding (argc, argv);
+	gchar const **args = go_shell_argv_to_glib_encoding (argc, argv);
 
 	gnm_pre_parse_init (args[0]);
 
-	ctx = gnumeric_arg_parse (argc, (gchar const **) args);
-        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	ctx = gnumeric_arg_parse (argc, args);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	if (gnumeric_show_version) {
 		g_print (_("gnumeric version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
@@ -306,8 +347,10 @@ main (int argc, char const *argv [])
 
 	with_gui = !func_def_file && !func_state_file && !split_funcdocs;
 
-	if (with_gui)
+	if (with_gui) {
+		check_pango_attr_list_splice_bug ();
 		gnm_session_init (args[0]);
+	}
 
 	/* TODO: Use the ioc.  Do this before calling handle_paint_events */
 	gnm_common_init (TRUE);
@@ -429,14 +472,7 @@ main (int argc, char const *argv [])
 #ifdef WITH_GNOME
 	bonobo_ui_debug_shutdown ();
 #endif
-
-	if (argv != (gchar const **) args) {
-		gint i;
-
-		for (i = 0; i < argc; ++i)
-			g_free (args[i]);
-		g_free (args);
-	}
+	go_shell_argv_to_glib_encoding_free ();
 
 	return 0;
 }
