@@ -119,25 +119,23 @@ gnumeric_background_set_gc (GnmStyle const *mstyle, GdkGC *gc,
 	 * Draw the background if the PATTERN is non 0
 	 * Draw a stipple too if the pattern is > 1
 	 */
-	pattern = mstyle_get_pattern (mstyle);
+	pattern = gnm_style_get_pattern (mstyle);
 	if (pattern > 0) {
 		const GdkColor *back;
-		GnmColor *back_col =
-			mstyle_get_color (mstyle, MSTYLE_COLOR_BACK);
+		GnmColor const *back_col = gnm_style_get_back_color (mstyle);
 		g_return_val_if_fail (back_col != NULL, FALSE);
 
-		back = is_selected ? &back_col->selected_color : &back_col->color;
+		back = is_selected ? &back_col->gdk_selected_color : &back_col->gdk_color;
 
 		if (pattern > 1) {
 			GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (canvas));
 			GdkDrawable *drawable = gdk_screen_get_root_window (screen);
 			GdkGCValues values;
-			GnmColor *pat_col =
-				mstyle_get_color (mstyle, MSTYLE_COLOR_PATTERN);
+			GnmColor const *pat_col = gnm_style_get_pattern_color (mstyle);
 			g_return_val_if_fail (pat_col != NULL, FALSE);
 
 			values.fill = GDK_OPAQUE_STIPPLED;
-			values.foreground = pat_col->color;
+			values.foreground = pat_col->gdk_color;
 			gdk_rgb_find_color (cmap, &values.foreground);
 			values.background = *back;
 			gdk_rgb_find_color (cmap, &values.background);
@@ -151,7 +149,6 @@ gnumeric_background_set_gc (GnmStyle const *mstyle, GdkGC *gc,
 			GdkGCValues values;
 
 			values.fill = GDK_SOLID;
-#warning "FIXME: verify the _foreground_ here."
 			values.foreground = *back;
 			gdk_rgb_find_color (cmap, &values.foreground);
 			gdk_gc_set_values (gc, &values, GDK_GC_FILL | GDK_GC_FOREGROUND);
@@ -182,10 +179,9 @@ gnumeric_background_set_pc (GnmStyle const *mstyle, GnomePrintContext *context)
 	 * Draw the background if the PATTERN is non 0
 	 * Draw a stipple too if the pattern is > 1
 	 */
-	pattern = mstyle_get_pattern (mstyle);
+	pattern = gnm_style_get_pattern (mstyle);
 	if (pattern > 0) {
-		GnmColor *back_col =
-			mstyle_get_color (mstyle, MSTYLE_COLOR_BACK);
+		GnmColor const *back_col = gnm_style_get_back_color (mstyle);
 
 		g_return_val_if_fail (back_col != NULL, FALSE);
 
@@ -211,9 +207,9 @@ gnumeric_background_set_pc (GnmStyle const *mstyle, GnomePrintContext *context)
 #endif
 
 			gnome_print_setrgbcolor (context,
-				back_col->color.red * grey[pattern]    / (double) 0xffff,
-				back_col->color.green * grey[pattern]  / (double) 0xffff,
-				back_col->color.blue * grey[pattern]   / (double) 0xffff);
+				back_col->gdk_color.red * grey[pattern]    / (double) 0xffff,
+				back_col->gdk_color.green * grey[pattern]  / (double) 0xffff,
+				back_col->gdk_color.blue * grey[pattern]   / (double) 0xffff);
 		}
 
 		/* This is a special case where the user has selected
@@ -221,21 +217,19 @@ gnumeric_background_set_pc (GnmStyle const *mstyle, GnomePrintContext *context)
 		 * color.
 		 */
 		if (pattern == 24) {
-			GnmColor *pat_col =
-				mstyle_get_color (mstyle, MSTYLE_COLOR_PATTERN);
+			GnmColor const *pat_col = gnm_style_get_pattern_color (mstyle);
 			g_return_val_if_fail (pat_col != NULL, FALSE);
 
 			gnome_print_setrgbcolor (context,
-				pat_col->color.red   / (double) 0xffff,
-				pat_col->color.green / (double) 0xffff,
-				pat_col->color.blue  / (double) 0xffff);
+				pat_col->gdk_color.red   / (double) 0xffff,
+				pat_col->gdk_color.green / (double) 0xffff,
+				pat_col->gdk_color.blue  / (double) 0xffff);
 
 		}
 #if 0
 		/* FIXME: How to do the other patterns? */
 		if (pattern > 1) {
-			GnmColor *pat_col =
-			mstyle_get_color (mstyle, MSTYLE_COLOR_PATTERN);
+			GnmColor const *pat_col = gnm_style_get_pattern_color (mstyle);
 			g_return_val_if_fail (pat_col != NULL, FALSE);
 
 			gdk_gc_set_fill (gc, GDK_OPAQUE_STIPPLED);
