@@ -4,6 +4,7 @@
 #include "gui-gnumeric.h"
 #include "sheet-control.h"
 #include <gtk/gtkwidget.h>
+#include <gtk/gtkselection.h>
 
 #define SHEET_CONTROL_GUI_TYPE        (sheet_control_gui_get_type ())
 #define SHEET_CONTROL_GUI(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), SHEET_CONTROL_GUI_TYPE, SheetControlGUI))
@@ -28,14 +29,17 @@ void scg_object_anchor_to_coords (SheetControlGUI const *scg,
 void scg_object_coords_to_anchor (SheetControlGUI const *scg,
 				  double const *coords, SheetObjectAnchor *in_out);
 
-void scg_objects_drag		(SheetControlGUI *scg, SheetObject *primary,
-				 gdouble dx, gdouble dy,
-				 int drag_type, gboolean symmetric);
+void scg_objects_drag		(SheetControlGUI *scg, GnmCanvas *gcanvas,
+				 SheetObject *primary,
+				 gdouble *dx, gdouble *dy,
+				 int drag_type, gboolean symmetric, gboolean snap_to_grid,
+				 gboolean is_mouse_move);
 void scg_objects_drag_commit	(SheetControlGUI *scg, int drag_type,
 				 gboolean created_objects);
-void scg_objects_nudge		(SheetControlGUI *scg,
-				 int drag_type, int dx, int dy,
-				 gboolean symmetric);
+void scg_objects_nudge		(SheetControlGUI *scg, GnmCanvas *gcanvas,
+				 int drag_type, double dx, double dy,
+				 gboolean symmetric, 
+				 gboolean snap_to_grid);
 
 void scg_object_select		(SheetControlGUI *scg, SheetObject *so);
 void scg_object_unselect	(SheetControlGUI *scg, SheetObject *so);
@@ -83,26 +87,28 @@ gboolean scg_special_cursor_bound_set (SheetControlGUI *scg, GnmRange const *r);
 void scg_set_left_col		(SheetControlGUI *scg, int new_first_col);
 void scg_set_top_row		(SheetControlGUI *scg, int new_first_row);
 
-void scg_colrow_resize_stop	(SheetControlGUI *scg);
-void scg_colrow_resize_start	(SheetControlGUI *scg,
-				 gboolean is_cols, int resize_first);
-void scg_colrow_resize_move	(SheetControlGUI *scg,
-				 gboolean is_cols, int resize_last);
+void scg_size_guide_start	(SheetControlGUI *scg, gboolean vert,
+				 int colrow, int width);
+void scg_size_guide_motion	(SheetControlGUI *scg, gboolean vert,
+				 int guide_pos);
+void scg_size_guide_stop	(SheetControlGUI *scg);
 
 typedef void (*SCGUIMoveFunc)	(SheetControlGUI *, int n,
 				 gboolean jump, gboolean horiz);
 void scg_queue_movement		(SheetControlGUI *scg,
 				 SCGUIMoveFunc	  handler,
 				 int n, gboolean jump, gboolean horiz);
+void  scg_paste_image (SheetControlGUI *scg, GnmRange *where, 
+		       guint8 const *data, unsigned len);
+void scg_drag_data_received (SheetControlGUI *scg, GtkWidget *source_widget,
+			     double x, double y, 
+			     GtkSelectionData *selection_data);
+void scg_drag_data_get      (SheetControlGUI *scg, 
+			     GtkSelectionData *selection_data);
 
 /* DO NOT USE THIS WITHOUT ALOT OF THOUGHT */
 GnmCanvas	   *scg_pane		(SheetControlGUI *scg, int pane);
 
 WorkbookControlGUI *scg_get_wbcg	(SheetControlGUI const *scg);
 
-/* FIXME : Move this around to a more reasonable location */
-GnmFont * scg_get_style_font (PangoContext *context,
-				Sheet const *sheet,
-				GnmStyle const *style);
-
 #endif /* GNUMERIC_SHEET_CONTROL_GUI_H */
