@@ -34,6 +34,12 @@ typedef enum {
 	UNDERLINE_DOUBLE = 2
 } GnmUnderline;
 
+typedef enum {
+	GO_FONT_SCRIPT_SUB	= -1,
+	GO_FONT_SCRIPT_STANDARD =  0,
+	GO_FONT_SCRIPT_SUPER	=  1
+} GOFontScript;
+
 typedef enum {
 	GNM_TEXT_DIR_RTL	= -1,
 	GNM_TEXT_DIR_CONTEXT	=  0,
