@@ -242,18 +242,22 @@ write_constraint_str (int lhs_col, int lhs_row, int rhs_col,
  * returns the coefficent of the first variable of the objective
  * function.
  */
-static inline gnm_float
-get_lp_coeff (GnmCell *target, GnmCell *change, gnm_float *x0)
+static gnm_float
+get_lp_coeff (GnmCell *target, GnmCell *change)
 {
-        gnm_float tmp = *x0;
+        gnm_float x0, x1;
+
+	cell_set_value (change, value_new_float (0.0));
+	cell_queue_recalc (change);
+	cell_eval (target);
+	x0 = value_get_as_float (target->value);
 
 	cell_set_value (change, value_new_float (1.0));
 	cell_queue_recalc (change);
-
 	cell_eval (target);
-	*x0 = value_get_as_float (target->value);
+	x1 = value_get_as_float (target->value);
 
-	return *x0 - tmp;
+	return x1 - x0;
 }
 
 /*
@@ -348,7 +352,7 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 {
         SolverProgram     program;
 	GnmCell          *target;
-	gnm_float         x, x0, base;
+	gnm_float         x;
 	int               i, n, ind;
 
 	/* Initialize the SolverProgram structure. */
@@ -359,12 +363,11 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 	clear_input_vars (param->n_variables, res);
 
 	cell_eval (target);
-	x0 = base = value_get_as_float (target->value);
 
 	if (param->options.model_type == SolverLPModel) {
 	        for (i = 0; i < param->n_variables; i++) {
 		        x = get_lp_coeff (target,
-					  solver_get_input_var (res, i), &x0);
+					  solver_get_input_var (res, i));
 			if (x != 0) {
 			        alg->set_obj_fn (program, i, x);
 				res->n_nonzeros_in_obj += 1;
@@ -385,19 +388,22 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 	for (i = ind = 0; i < param->n_total_constraints; i++) {
 	        SolverConstraint const *c = solver_get_constraint (res, i);
 		GTimeVal cur_time;
+		const GnmValue *val;
 
 		target = sheet_cell_get (sheet, c->lhs.col, c->lhs.row);
-		cell_eval (target);
+		if (target) {
+			cell_eval (target);
+			val = target->value;
+		} else
+			val = NULL;
 
 		/* Check that LHS is a number type. */
-		if (! (target->value == NULL ||
-		       VALUE_IS_EMPTY (target->value) ||
-		       VALUE_IS_NUMBER (target->value))) {
-		          *errmsg = _("The LHS cells should contain formulas "
-				      "that yield proper numerical values.  "
-				      "Specify valid LHS entries.");
-			  solver_results_free (res);
-			  return NULL;
+		if (val == NULL || !VALUE_IS_NUMBER (val)) {
+			*errmsg = _("The LHS cells should contain formulas "
+				    "that yield proper numerical values.  "
+				    "Specify valid LHS entries.");
+			solver_results_free (res);
+			return NULL;
 		}
 
 		if (c->type == SolverINT) {
@@ -417,31 +423,33 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 		        continue;
 		}
 		clear_input_vars (param->n_variables, res);
-		x0 = base = value_get_as_float (target->value);
 		for (n = 0; n < param->n_variables; n++) {
 		        x = get_lp_coeff (target,
-					  solver_get_input_var (res, n), &x0);
+					  solver_get_input_var (res, n));
 			if (x != 0) {
 			        res->n_nonzeros_in_mat += 1;
 				alg->set_constr_mat_fn (program, n, ind, x);
 				res->constr_coeff[i][n] = x;
 			}
 		}
+
 		target = sheet_cell_get (sheet, c->rhs.col, c->rhs.row);
-		cell_eval (target);
+		if (target) {
+			cell_eval (target);
+			val = target->value;
+		} else
+			val = NULL;
 
 		/* Check that RHS is a number type. */
-		if (! (target->value == NULL ||
-		       VALUE_IS_EMPTY (target->value) ||
-		       VALUE_IS_NUMBER (target->value))) {
-		          *errmsg = _("The RHS cells should contain proper "
-				      "numerical values only.  Specify valid "
-				      "RHS entries.");
-			  solver_results_free (res);
-			  return NULL;
+		if (val == NULL || !VALUE_IS_NUMBER (val)) {
+			*errmsg = _("The RHS cells should contain proper "
+				    "numerical values only.  Specify valid "
+				    "RHS entries.");
+			solver_results_free (res);
+			return NULL;
 		}
 
-		x = value_get_as_float (target->value) - base;
+		x = value_get_as_float (val);
 		alg->set_constr_fn (program, ind, c->type, x);
 		res->rhs[i] = x; 
 		ind++;
@@ -491,7 +499,7 @@ lp_qp_solver_init (Sheet *sheet, const SolverParameters *param,
 	}
 	if (alg->set_option_fn (program, SolverOptMaxTimeSec, NULL, &start_time,
 				&(param->options.max_time_sec))) {
-		*errmsg = _("Failure setting setting the maximum solving time with this solver, try a different algorithm.");
+		*errmsg = _("Failure setting the maximum solving time with this solver, try a different algorithm.");
 		solver_results_free (res);
 	        return NULL;
 	}
