@@ -514,7 +514,7 @@ value_release (GnmValue *value)
 	g_return_if_fail (value != NULL);
 
 	if (VALUE_FMT (value) != NULL)
-		style_format_unref (VALUE_FMT (value));
+		go_format_unref (VALUE_FMT (value));
 
 	switch (value->type) {
 	case VALUE_EMPTY:
@@ -709,8 +709,8 @@ value_equal (GnmValue const *a, GnmValue const *b)
 		return TRUE;
 
 	case VALUE_CELLRANGE:
-		return	cellref_equal (&a->v_range.cell.a, &b->v_range.cell.a) &&
-			cellref_equal (&a->v_range.cell.b, &b->v_range.cell.b);
+		return	gnm_cellref_equal (&a->v_range.cell.a, &b->v_range.cell.a) &&
+			gnm_cellref_equal (&a->v_range.cell.b, &b->v_range.cell.b);
 
 	case VALUE_ARRAY:
 		if (a->v_array.x == b->v_array.x && a->v_array.y == b->v_array.y) {
@@ -763,8 +763,8 @@ value_hash (GnmValue const *v)
 
 	case VALUE_CELLRANGE:
 		/* FIXME: take sheet into account?  */
-		return (cellref_hash (&v->v_range.cell.a) * 3) ^
-			cellref_hash (&v->v_range.cell.b);
+		return (gnm_cellref_hash (&v->v_range.cell.a) * 3) ^
+			gnm_cellref_hash (&v->v_range.cell.b);
 
 	case VALUE_ARRAY: {
 		int i;
@@ -1390,9 +1390,9 @@ void
 value_set_fmt (GnmValue *v, GOFormat const *fmt)
 {
 	if (fmt != NULL)
-		style_format_ref ((GOFormat *)fmt);
+		go_format_ref ((GOFormat *)fmt);
 	if (VALUE_FMT (v) != NULL)
-		style_format_unref (VALUE_FMT (v));
+		go_format_unref (VALUE_FMT (v));
 	VALUE_FMT (v) = (GOFormat *)fmt;
 }
 
