@@ -3,7 +3,7 @@
 /*
  * wbcg-actions.c: The callbacks and tables for all the menus and stock toolbars
  *
- * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2005 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -166,13 +166,12 @@ static GNM_ACTION_DEF (cb_file_quit)
 	if (discard_all) {
 		workbook_set_dirty (wb_control_workbook (wbc), FALSE);
 		g_object_unref (wb_control_workbook (wbc));
-		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
+		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next) {
 			g_object_unref (ptr->data);
-	} else
-	/* only close pristine books if nothing was canceled. */
-	if (ok && wbcg_close_if_user_permits (wbcg,
-					      wb_control_view (wbc), TRUE, TRUE, ask_user)
-	    > 0)
+		}
+	} else if (ok && wbcg_close_if_user_permits (wbcg, wb_control_view (wbc),
+						     TRUE, TRUE, ask_user) > 0)
+		/* only close pristine books if nothing was canceled. */
 		for (ptr = clean_no_closed; ptr != NULL ; ptr = ptr->next)
 			g_object_unref (ptr->data);
 
@@ -204,7 +203,7 @@ static GNM_ACTION_DEF (cb_edit_delete_rows)
 	WorkbookControl *wbc   = WORKBOOK_CONTROL (wbcg);
 	SheetView       *sv    = wb_control_cur_sheet_view (wbc);
 	Sheet           *sheet = wb_control_cur_sheet (wbc);
-	GnmRange const *sel;
+	GnmRange const  *sel;
 	int rows;
 
 	if (!(sel = selection_first_range (sv, GO_CMD_CONTEXT (wbc), _("Delete"))))
@@ -583,7 +582,7 @@ static GNM_ACTION_DEF (cb_insert_current_date_time)
 		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_float (
 			datetime_timet_to_serial_raw (time (NULL), workbook_date_conv (wb)));
-		char *txt = format_value (style_format_default_date_time (), v, NULL, -1,
+		char *txt = format_value (go_format_default_date_time (), v, NULL, -1,
 				workbook_date_conv (wb));
 		value_release (v);
 		wb_control_edit_line_set (WORKBOOK_CONTROL (wbcg), txt);
@@ -596,8 +595,8 @@ static GNM_ACTION_DEF (cb_insert_current_date)
 		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_int (
 			datetime_timet_to_serial (time (NULL), workbook_date_conv (wb)));
-		char *txt = format_value (style_format_default_date (), v, NULL, -1,
-				workbook_date_conv (wb));
+		char *txt = format_value (go_format_default_date (), v, NULL, -1,
+			workbook_date_conv (wb));
 		value_release (v);
 		wb_control_edit_line_set (WORKBOOK_CONTROL (wbcg), txt);
 		g_free (txt);
@@ -610,7 +609,7 @@ static GNM_ACTION_DEF (cb_insert_current_time)
 		Workbook const *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 		GnmValue *v = value_new_float (
 			datetime_timet_to_seconds (time (NULL)) / (24.0 * 60 * 60));
-		char *txt = format_value (style_format_default_time (), v, NULL, -1,
+		char *txt = format_value (go_format_default_time (), v, NULL, -1,
 				workbook_date_conv (wb));
 		value_release (v);
 		wb_control_edit_line_set (WORKBOOK_CONTROL (wbcg), txt);
@@ -720,7 +719,7 @@ static GNM_ACTION_DEF (cb_tools_ftest)		{ dialog_ftest_tool (wbcg, wbcg_cur_shee
 static GNM_ACTION_DEF (cb_tools_random_generator) { dialog_random_tool (wbcg, wbcg_cur_sheet (wbcg)); }
 static GNM_ACTION_DEF (cb_data_sort)		{ dialog_cell_sort (wbcg); }
 static GNM_ACTION_DEF (cb_data_shuffle)		{ dialog_shuffle (wbcg); }
-static GNM_ACTION_DEF (cb_data_import_text)	{ gui_file_open (wbcg, "Gnumeric_stf:stf_druid"); }
+static GNM_ACTION_DEF (cb_data_import_text)	{ gui_file_open (wbcg, "Gnumeric_stf:stf_assistant"); }
 
 static GNM_ACTION_DEF (cb_auto_filter)
 {
@@ -1063,7 +1062,7 @@ static GNM_ACTION_DEF (cmd_create_ellipse)
 	{ create_object (wbcg, GNM_SO_FILLED_TYPE, "is-oval", TRUE, NULL); }
 
 void
-wbcg_set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
+wbcg_set_selection_halign (WorkbookControlGUI *wbcg, GnmHAlign halign)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView	*wb_view;
@@ -1076,11 +1075,11 @@ wbcg_set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
 	 * then revert to general */
 	wb_view = wb_control_view (wbc);
 	style = wb_view->current_format;
-	if (mstyle_get_align_h (style) == halign)
+	if (gnm_style_get_align_h (style) == halign)
 		halign = HALIGN_GENERAL;
 
-	style = mstyle_new ();
-	mstyle_set_align_h (style, halign);
+	style = gnm_style_new ();
+	gnm_style_set_align_h (style, halign);
 	cmd_selection_format (wbc, style, NULL, _("Set Horizontal Alignment"));
 }
 
@@ -1094,7 +1093,7 @@ static GNM_ACTION_DEF (cb_center_across_selection)
 	{ wbcg_set_selection_halign (wbcg, HALIGN_CENTER_ACROSS_SELECTION); }
 
 void
-wbcg_set_selection_valign (WorkbookControlGUI *wbcg, StyleVAlignFlags valign)
+wbcg_set_selection_valign (WorkbookControlGUI *wbcg, GnmVAlign valign)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView	*wb_view;
@@ -1107,14 +1106,14 @@ wbcg_set_selection_valign (WorkbookControlGUI *wbcg, StyleVAlignFlags valign)
 	 * then revert to general */
 	wb_view = wb_control_view (wbc);
 	style = wb_view->current_format;
-	if (mstyle_get_align_h (style) == valign) {
+	if (gnm_style_get_align_h (style) == valign) {
 		if (valign == VALIGN_BOTTOM)
 			return;
 		valign = VALIGN_BOTTOM;
 	}
 
-	style = mstyle_new ();
-	mstyle_set_align_v (style, valign);
+	style = gnm_style_new ();
+	gnm_style_set_align_v (style, valign);
 	cmd_selection_format (wbc, style, NULL, _("Set Vertical Alignment"));
 }
 
@@ -1159,7 +1158,7 @@ static GNM_ACTION_DEF (cb_unmerge_cells)
 
 static void
 toggle_font_attr (WorkbookControlGUI *wbcg, GtkToggleAction *act,
-		  MStyleElementType t, unsigned true_val, unsigned false_val)
+		  GnmStyleElement t, unsigned true_val, unsigned false_val)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	GnmStyle *new_style;
@@ -1190,18 +1189,22 @@ toggle_font_attr (WorkbookControlGUI *wbcg, GtkToggleAction *act,
 		case MSTYLE_FONT_STRIKETHROUGH:
 			attr = pango_attr_strikethrough_new (val);
 			break;
+		case MSTYLE_FONT_SCRIPT:
+			attr = pango_attr_rise_new (5000 * val);
+			break;
 		}
 		wbcg_edit_add_markup (wbcg, attr);
 		return;
 	}
 
-	new_style = mstyle_new ();
+	new_style = gnm_style_new ();
 	switch (t) {
 	default :
-	case MSTYLE_FONT_BOLD:	 	mstyle_set_font_bold (new_style, val); break;
-	case MSTYLE_FONT_ITALIC:	mstyle_set_font_italic (new_style, val); break;
-	case MSTYLE_FONT_UNDERLINE:	mstyle_set_font_uline (new_style, val); break;
-	case MSTYLE_FONT_STRIKETHROUGH: mstyle_set_font_strike (new_style, val); break;
+	case MSTYLE_FONT_BOLD:	 	gnm_style_set_font_bold (new_style, val); break;
+	case MSTYLE_FONT_ITALIC:	gnm_style_set_font_italic (new_style, val); break;
+	case MSTYLE_FONT_UNDERLINE:	gnm_style_set_font_uline (new_style, val); break;
+	case MSTYLE_FONT_STRIKETHROUGH: gnm_style_set_font_strike (new_style, val); break;
+	case MSTYLE_FONT_SCRIPT:	gnm_style_set_font_script (new_style, val); break;
 	};
 
 	cmd_selection_format (wbc, new_style, NULL, _("Set Font Style"));
@@ -1217,51 +1220,55 @@ static void cb_font_double_underline (GtkToggleAction *act, WorkbookControlGUI *
 	{ toggle_font_attr (wbcg, act, MSTYLE_FONT_UNDERLINE, UNDERLINE_DOUBLE, UNDERLINE_NONE); }
 static void cb_font_strikethrough (GtkToggleAction *act, WorkbookControlGUI *wbcg)
 	{ toggle_font_attr (wbcg, act, MSTYLE_FONT_STRIKETHROUGH, TRUE, FALSE); }
+static void cb_font_subscript (GtkToggleAction *act, WorkbookControlGUI *wbcg)
+	{ toggle_font_attr (wbcg, act, MSTYLE_FONT_SCRIPT, GO_FONT_SCRIPT_SUB, GO_FONT_SCRIPT_STANDARD); }
+static void cb_font_superscript (GtkToggleAction *act, WorkbookControlGUI *wbcg)
+	{ toggle_font_attr (wbcg, act, MSTYLE_FONT_SCRIPT, GO_FONT_SCRIPT_SUPER, GO_FONT_SCRIPT_STANDARD); }
 
 static void
 apply_number_format (WorkbookControlGUI *wbcg,
 		     char const *translated_format, char const *descriptor)
 {
-	GnmStyle *mstyle = mstyle_new ();
-	mstyle_set_format_text (mstyle, translated_format);
+	GnmStyle *mstyle = gnm_style_new ();
+	gnm_style_set_format_text (mstyle, translated_format);
 	cmd_selection_format (WORKBOOK_CONTROL (wbcg), mstyle, NULL, descriptor);
 }
 
 static GNM_ACTION_DEF (cb_format_as_number)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_NUMBER][0], _("Format as Number"));
+		go_format_builtins [GO_FORMAT_NUMBER][0], _("Format as Number"));
 }
 static GNM_ACTION_DEF (cb_format_as_currency)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_CURRENCY][0], _("Format as Currency"));
+		go_format_builtins [GO_FORMAT_CURRENCY][0], _("Format as Currency"));
 }
 static GNM_ACTION_DEF (cb_format_as_accounting)
 {
 	apply_number_format (wbcg,
-		cell_formats[FMT_ACCOUNT][2], _("Format as Accounting"));
+		go_format_builtins[GO_FORMAT_ACCOUNTING][2], _("Format as Accounting"));
 }
 
 static GNM_ACTION_DEF (cb_format_as_percentage)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_PERCENT][0], _("Format as Percentage"));
+		go_format_builtins [GO_FORMAT_PERCENTAGE][0], _("Format as Percentage"));
 }
 static GNM_ACTION_DEF (cb_format_as_scientific)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_SCIENCE][0], _("Format as Scientific"));
+		go_format_builtins [GO_FORMAT_SCIENTIFIC][0], _("Format as Scientific"));
 }
 static GNM_ACTION_DEF (cb_format_as_time)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_DATE][0], _("Format as Date"));
+		go_format_builtins [GO_FORMAT_DATE][0], _("Format as Date"));
 }
 static GNM_ACTION_DEF (cb_format_as_date)
 {
 	apply_number_format (wbcg,
-		cell_formats [FMT_TIME][0], _("Format as Time"));
+		go_format_builtins [GO_FORMAT_TIME][0], _("Format as Time"));
 }
 
 /* Adds borders to all the selected regions on the sheet.
@@ -1304,21 +1311,21 @@ modify_format (WorkbookControlGUI *wbcg,
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	new_fmt = (*format_modify_fn) (mstyle_get_format (wbv->current_format));
+	new_fmt = (*format_modify_fn) (gnm_style_get_format (wbv->current_format));
 	if (new_fmt != NULL) {
-		GnmStyle *style = mstyle_new ();
-		mstyle_set_format (style, new_fmt);
+		GnmStyle *style = gnm_style_new ();
+		gnm_style_set_format (style, new_fmt);
 		cmd_selection_format (wbc, style, NULL, descriptor);
-		style_format_unref (new_fmt);
+		go_format_unref (new_fmt);
 	}
 }
 
 static GNM_ACTION_DEF (cb_format_inc_precision)
-	{ modify_format (wbcg, &format_add_decimal, _("Increase precision")); }
+	{ modify_format (wbcg, &go_format_inc_precision, _("Increase precision")); }
 static GNM_ACTION_DEF (cb_format_dec_precision)
-	{ modify_format (wbcg, &format_remove_decimal, _("Decrease precision")); }
+	{ modify_format (wbcg, &go_format_dec_precision, _("Decrease precision")); }
 static GNM_ACTION_DEF (cb_format_with_thousands)
-	{ modify_format (wbcg, &format_toggle_thousands, _("Toggle thousands separator")); }
+	{ modify_format (wbcg, &go_format_toggle_1000sep, _("Toggle thousands separator")); }
 
 static GNM_ACTION_DEF (cb_format_inc_indent)
 {
@@ -1330,13 +1337,13 @@ static GNM_ACTION_DEF (cb_format_inc_indent)
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	i = mstyle_get_indent (wbv->current_format);
+	i = gnm_style_get_indent (wbv->current_format);
 	if (i < 20) {
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 
-		if (HALIGN_LEFT != mstyle_get_align_h (wbv->current_format))
-			mstyle_set_align_h (style, HALIGN_LEFT);
-		mstyle_set_indent (style, i+1);
+		if (HALIGN_LEFT != gnm_style_get_align_h (wbv->current_format))
+			gnm_style_set_align_h (style, HALIGN_LEFT);
+		gnm_style_set_indent (style, i+1);
 		cmd_selection_format (wbc, style, NULL,
 			    _("Increase Indent"));
 	}
@@ -1352,11 +1359,11 @@ static GNM_ACTION_DEF (cb_format_dec_indent)
 	g_return_if_fail (wbv != NULL);
 	g_return_if_fail (wbv->current_format != NULL);
 
-	i = mstyle_get_indent (wbv->current_format);
+	i = gnm_style_get_indent (wbv->current_format);
 	if (i > 0) {
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 
-		mstyle_set_indent (style, i-1);
+		gnm_style_set_indent (style, i-1);
 		cmd_selection_format (wbc, style, NULL,
 			    _("Decrease Indent"));
 	}
@@ -1421,7 +1428,7 @@ static GNM_ACTION_DEF (cb_format_row_unhide)
 }
 
 /* Actions that are always sensitive */
-static const GtkActionEntry permanent_actions[] = {
+static GtkActionEntry const permanent_actions[] = {
 	{ "MenuFile",		NULL, N_("_File") },
 	{ "MenuEdit",		NULL, N_("_Edit") },
 		{ "MenuEditClear",	GTK_STOCK_CLEAR, N_("C_lear") },
@@ -1451,6 +1458,13 @@ static const GtkActionEntry permanent_actions[] = {
 		{ "MenuExternalData",	NULL,	N_("Get _External Data") },
 	{ "MenuHelp",	NULL,	N_("_Help") },
 
+	{ "FileClose", GTK_STOCK_CLOSE, NULL,
+		NULL, N_("Close the current file"),
+		G_CALLBACK (cb_file_close) },
+	{ "FileQuit", GTK_STOCK_QUIT, NULL,
+		NULL, N_("Quit the application"),
+		G_CALLBACK (cb_file_quit) },
+
 	{ "EditCut", GTK_STOCK_CUT, NULL,
 		NULL, N_("Cut the selection"),
 		G_CALLBACK (cb_edit_cut) },
@@ -1484,7 +1498,7 @@ static const GtkActionEntry permanent_actions[] = {
 		G_CALLBACK (cb_repeat) }
 };
 
-static const GtkActionEntry actions[] = {
+static GtkActionEntry const actions[] = {
 /* File */
 	{ "FileNew", GTK_STOCK_NEW, NULL,
 		NULL, N_("Create a new workbook"),
@@ -1516,14 +1530,8 @@ static const GtkActionEntry actions[] = {
 	{ "FilePreferences", GTK_STOCK_PREFERENCES, N_("Pre_ferences..."),
 		NULL, N_("Change Gnumeric Preferences"),
 		G_CALLBACK (cb_file_preferences) },
-	{ "FileClose", GTK_STOCK_CLOSE, NULL,
-		NULL, N_("Close the current file"),
-		G_CALLBACK (cb_file_close) },
-	{ "FileQuit", GTK_STOCK_QUIT, NULL,
-		NULL, N_("Quit the application"),
-		G_CALLBACK (cb_file_quit) },
 
-#warning new hook put here to avoid patch conflict
+/* new hook put here to avoid patch conflict */
 	{ "FileSummary_new", GTK_STOCK_PROPERTIES, N_("NEW Proper_ties..."),
 		NULL, N_("Edit descriptive information"),
 		G_CALLBACK (cb_new_doc_metadata) },
@@ -1573,6 +1581,9 @@ static const GtkActionEntry actions[] = {
 	{ "EditSelectInputs", NULL, N_("Select _Inputs"),
 		"<control>bracketleft", N_("Select all the cells are used by the current edit cell"),
 		G_CALLBACK (cb_edit_select_inputs) },
+	{ "EditMetadata", NULL, N_("Edit Metadata"),
+		NULL, N_("Edit the document's extra information (metadata)"),
+		G_CALLBACK (cb_new_doc_metadata) },
 
 /* Edit -> Fill */
 	{ "EditFillAutofill", NULL, N_("Auto_fill"),
@@ -1697,7 +1708,7 @@ static const GtkActionEntry actions[] = {
 		"<control>F3", N_("Edit sheet and workbook names"),
 		G_CALLBACK (cb_define_name) },
 	{ "PasteNames", GTK_STOCK_PASTE, NULL,
-		"F3", N_("Paste the definition a name, or names"),
+		"F3", N_("Paste the definition of a name or names"),
 		G_CALLBACK (cb_paste_names) },
 #if 0
 	{ "EditGenerateName", NULL,  N_("_Auto generate names..."),
@@ -2034,7 +2045,7 @@ TOGGLE_HANDLER (outline_symbols_below, "display-outlines-below")
 TOGGLE_HANDLER (outline_symbols_right, "display-outlines-right")
 TOGGLE_HANDLER (use_r1c1, "use-r1c1")
 
-static const GtkToggleActionEntry toggle_actions[] = {
+static GtkToggleActionEntry const toggle_actions[] = {
 	{ "SheetDisplayOutlines", NULL, N_("Display _Outlines"),
 		"<control>8", N_("Toggle whether or not to display outline groups"),
 		G_CALLBACK (cb_sheet_pref_display_outlines) },
@@ -2100,13 +2111,13 @@ static const GtkToggleActionEntry toggle_actions[] = {
 	        G_CALLBACK (cb_view_statusbar), TRUE },
 
 	{ "ViewFullScreen", GTK_STOCK_ZOOM_FIT,
-		N_("F_ull Screen..."), "F11",
+		N_("F_ull Screen"), "F11",
 		N_("in or out"), G_CALLBACK (cb_view_fullscreen), FALSE }
 };
 
-static const GtkToggleActionEntry font_toggle_actions[] = {
+static GtkToggleActionEntry const font_toggle_actions[] = {
 	{ "FontBold", GTK_STOCK_BOLD,
-		N_("_Bold"), "<control>B",	/* ALSO "<control>2" */
+		N_("_Bold"), "<control>b",	/* ALSO "<control>2" */
 		N_("Bold"), G_CALLBACK (cb_font_bold), FALSE },
 	{ "FontItalic", GTK_STOCK_ITALIC,
 		N_("_Italic"), "<control>i",	/* ALSO "<control>3" */
@@ -2114,13 +2125,18 @@ static const GtkToggleActionEntry font_toggle_actions[] = {
 	{ "FontUnderline", GTK_STOCK_UNDERLINE,
 		N_("_Underline"), "<control>u",	/* ALSO "<control>4" */
 		N_("Underline"), G_CALLBACK (cb_font_underline), FALSE },
-	{ "FontStrikeThrough", GTK_STOCK_UNDERLINE,
+	{ "FontStrikeThrough", GTK_STOCK_STRIKETHROUGH,
 		N_("_Strike Through"), "<control>5",
 		N_("Strike Through"), G_CALLBACK (cb_font_strikethrough), FALSE },
-#warning "Add double underline icon"
-	{ "FontDoubleUnderline", GTK_STOCK_UNDERLINE,
+	{ "FontDoubleUnderline", "stock_text_underlined-double",	/* from icon theme */
 		N_("_Double Underline"), "<control><shift>d",
 		N_("Double Underline"), G_CALLBACK (cb_font_double_underline), FALSE },
+	{ "FontSuperscript", "stock_superscript",	/* from icon theme */
+		N_("Su_perscript"), "<control>asciicircum",
+		N_("Superscript"), G_CALLBACK (cb_font_superscript), FALSE },
+	{ "FontSubscript", "stock_subscript",	/* from icon theme */
+		N_("Subscrip_t"), "<control>underscore",
+		N_("Subscript"), G_CALLBACK (cb_font_subscript), FALSE }
 };
 
 void wbcg_register_actions (WorkbookControlGUI *wbcg,
