@@ -6,7 +6,7 @@
  *   Miguel de Icaza (miguel@ximian.com)
  *   Jody Goldberg (jody@gnome.org)
  *
- * (C) 2000-2001 Ximian, Inc.
+ * (C) 2000-2005 Ximian, Inc.
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
@@ -49,7 +49,7 @@ wbcg_auto_complete_destroy (WorkbookControlGUI *wbcg)
 
 	if (wbcg->edit_line.signal_changed) {
 		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
-			wbcg->edit_line.signal_changed);
+					     wbcg->edit_line.signal_changed);
 		wbcg->edit_line.signal_changed = 0;
 	}
 
@@ -59,7 +59,6 @@ wbcg_auto_complete_destroy (WorkbookControlGUI *wbcg)
 	}
 
 	wbcg->auto_completing = FALSE;
-
 }
 
 /**
@@ -121,7 +120,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		char const *expr_txt = NULL;
 
 		/* BE CAREFUL the standard fmts must not NOT include '@' */
-		GnmValue *value = format_match (txt, mstyle_get_format (mstyle),
+		GnmValue *value = format_match (txt, gnm_style_get_format (mstyle),
 						workbook_date_conv (sheet->workbook));
 		if (value != NULL)
 			value_release (value);
@@ -162,9 +161,10 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 
 				/* set focus _before_ selection.  gtk2 seems to
 				 * screw with selection in gtk_entry_grab_focus
-				 */
-				gtk_window_set_focus (GTK_WINDOW (wbcg->toplevel),
-						      GTK_WIDGET (wbcg_get_entry (wbcg)));
+				 * (no longer required now that we clear
+				 * gtk-entry-select-on-focus) */
+				gtk_window_set_focus (wbcg_toplevel (wbcg),
+					(GtkWidget *) wbcg_get_entry (wbcg));
 
 				if (perr.begin_char != 0 || perr.end_char != 0) {
 					int offset = expr_txt - txt;
@@ -218,9 +218,9 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 			result = WBC_EDIT_REJECT;
 			command_undo (wbc);
 			if (valid == VALIDATION_STATUS_INVALID_EDIT) {
-				gtk_window_set_focus (GTK_WINDOW (wbcg->toplevel),
-						      GTK_WIDGET (wbcg_get_entry (wbcg)));
-				  return FALSE;
+				gtk_window_set_focus (wbcg_toplevel (wbcg),
+					(GtkWidget *) wbcg_get_entry (wbcg));
+				return FALSE;
 			}
 		}
 	} else {
@@ -245,6 +245,28 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		wbcg_edit_detach_guru (wbcg);
 		gtk_widget_destroy (w);
 	}
+
+	if (wbcg->edit_line.signal_insert) {
+		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
+					     wbcg->edit_line.signal_insert);
+		wbcg->edit_line.signal_insert = 0;
+	}
+	if (wbcg->edit_line.signal_delete) {
+		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
+					     wbcg->edit_line.signal_delete);
+		wbcg->edit_line.signal_delete = 0;
+	}
+	if (wbcg->edit_line.signal_cursor_pos) {
+		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
+					     wbcg->edit_line.signal_cursor_pos);
+		wbcg->edit_line.signal_cursor_pos = 0;
+	}
+	if (wbcg->edit_line.signal_selection_bound) {
+		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
+					     wbcg->edit_line.signal_selection_bound);
+		wbcg->edit_line.signal_selection_bound = 0;
+	}
+
 	if (wbcg->edit_line.full_content != NULL) {
 		pango_attr_list_unref (wbcg->edit_line.full_content);
 		pango_attr_list_unref (wbcg->edit_line.markup);
@@ -252,18 +274,6 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		wbcg->edit_line.full_content =
 			wbcg->edit_line.markup =
 			wbcg->edit_line.cur_fmt = NULL;
-		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
-			wbcg->edit_line.signal_insert);
-		wbcg->edit_line.signal_insert = 0;
-		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
-			wbcg->edit_line.signal_delete);
-		wbcg->edit_line.signal_delete = 0;
-		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
-			wbcg->edit_line.signal_cursor_pos);
-		wbcg->edit_line.signal_cursor_pos = 0;
-		g_signal_handler_disconnect (wbcg_get_entry (wbcg),
-			wbcg->edit_line.signal_selection_bound);
-		wbcg->edit_line.signal_selection_bound = 0;
 	}
 	/* set pos to 0, to ensure that if we start editing by clicking on the
 	 * editline at the last position, we'll get the right style feedback */
@@ -297,9 +307,8 @@ workbook_edit_complete_notify (char const *text, void *closure)
 }
 
 static void
-entry_changed (GtkEntry *entry, void *data)
+cb_entry_changed (GtkEntry *entry, WorkbookControlGUI *wbcg)
 {
-	WorkbookControlGUI *wbcg = data;
 	char const *text;
 	int text_len;
 	WorkbookView *wbv = wb_control_view (WORKBOOK_CONTROL (wbcg));
@@ -310,14 +319,6 @@ entry_changed (GtkEntry *entry, void *data)
 	if (text_len > wbcg->auto_max_size)
 		wbcg->auto_max_size = text_len;
 
-	/*
-	 * Turn off auto-completion if the user has edited or the text
-	 * does not begin with an alphabetic character.
-	 */
-	if (text_len < wbcg->auto_max_size ||
-	    !g_unichar_isalpha (g_utf8_get_char (text)))
-		wbcg->auto_completing = FALSE;
-
 	if (wbv->do_auto_completion && wbcg->auto_completing)
 		complete_start (wbcg->auto_complete, text);
 }
@@ -403,15 +404,26 @@ cb_entry_insert_text (GtkEditable *editable,
 	char const *str = gtk_entry_get_text (GTK_ENTRY (editable));
 	int pos_in_bytes = g_utf8_offset_to_pointer (str, *pos_in_chars) - str;
 
-	(void)pango_attr_list_filter (wbcg->edit_line.cur_fmt,
-		cb_set_attr_list_len,
-		GINT_TO_POINTER (len_bytes));
+	if (wbcg->auto_completing &&
+	    len_bytes != 0 &&
+	    (!g_unichar_isalpha (g_utf8_get_char (text)) ||
+	     *pos_in_chars != GTK_ENTRY (editable)->text_length)) {
+		wbcg->auto_completing = FALSE;
+	}
 
-	gnm_pango_attr_list_splice (wbcg->edit_line.full_content,
-		wbcg->edit_line.cur_fmt, pos_in_bytes, len_bytes);
+	if (wbcg->edit_line.full_content) {
+		(void)pango_attr_list_filter (wbcg->edit_line.cur_fmt,
+					      cb_set_attr_list_len,
+					      GINT_TO_POINTER (len_bytes));
 
-	gnm_pango_attr_list_splice (wbcg->edit_line.markup,
-		wbcg->edit_line.cur_fmt, pos_in_bytes, len_bytes);
+		gnm_pango_attr_list_splice (wbcg->edit_line.full_content,
+					    wbcg->edit_line.cur_fmt,
+					    pos_in_bytes, len_bytes);
+
+		gnm_pango_attr_list_splice (wbcg->edit_line.markup,
+					    wbcg->edit_line.cur_fmt,
+					    pos_in_bytes, len_bytes);
+	}
 }
 
 static GSList *
@@ -433,23 +445,51 @@ attrs_at_byte (PangoAttrList *alist, guint bytepos)
 	return attrs;
 }
 
+/* Find the markup to be used for new characters.  */
+static void
+set_cur_fmt (WorkbookControlGUI *wbcg, int target_pos_in_bytes)
+{
+	PangoAttrList *new_list = pango_attr_list_new ();
+	GSList *ptr, *attrs = attrs_at_byte (wbcg->edit_line.markup, target_pos_in_bytes);
+
+	for (ptr = attrs; ptr != NULL ; ptr = ptr->next) {
+		PangoAttribute *attr = ptr->data;
+		attr->start_index = 0;
+		attr->end_index = INT_MAX;
+		pango_attr_list_change (new_list, attr);
+	}
+	g_slist_free (attrs);
+	if (wbcg->edit_line.cur_fmt)
+		pango_attr_list_unref (wbcg->edit_line.cur_fmt);
+	wbcg->edit_line.cur_fmt = new_list;
+}
+
 static void
 cb_entry_cursor_pos (WorkbookControlGUI *wbcg)
 {
 	guint start, end, target_pos_in_chars, target_pos_in_bytes;
 	GtkEditable *entry = GTK_EDITABLE (wbcg_get_entry (wbcg));
 	char const *str = gtk_entry_get_text (GTK_ENTRY (entry));
+	int edit_pos = gtk_editable_get_position (entry);
 
 	if (str[0] == 0)
 		return;
 
+	if (edit_pos != GTK_ENTRY (entry)->text_length) {
+		/* The cursor is no longer at the end.  */
+		wbcg->auto_completing = FALSE;
+	}
+
+	if (!wbcg->edit_line.full_content)
+		return;
+
 	/* 1) Use first selected character if there is a selection
 	 * 2) Use the character just before the edit pos if it exists
 	 * 3) Use the first character */
 	if (gtk_editable_get_selection_bounds (entry, &start, &end))
 		target_pos_in_chars = start;
 	else {
-		target_pos_in_chars = gtk_editable_get_position (entry);
+		target_pos_in_chars = edit_pos;
 		if (target_pos_in_chars > 0)
 			target_pos_in_chars--;
 	}
@@ -458,33 +498,19 @@ cb_entry_cursor_pos (WorkbookControlGUI *wbcg)
 
 	/* Make bold/italic/etc buttons show the right thing.  */
 	{
-		GnmStyle *style = mstyle_new ();
+		GnmStyle *style = gnm_style_new ();
 		GSList *ptr, *attrs = attrs_at_byte (wbcg->edit_line.full_content, target_pos_in_bytes);
 		for (ptr = attrs; ptr != NULL ; ptr = ptr->next) {
 			PangoAttribute *attr = ptr->data;
-			mstyle_set_from_pango_attribute (style, attr);
+			gnm_style_set_from_pango_attribute (style, attr);
 			pango_attribute_destroy (attr);
 		}
 		wb_control_style_feedback (WORKBOOK_CONTROL (wbcg), style);
-		mstyle_unref (style);
+		gnm_style_unref (style);
 		g_slist_free (attrs);
 	}
 
-	/* Find the markup to be used for new characters.  */
-	{
-		PangoAttrList *new_list = pango_attr_list_new ();
-		GSList *ptr, *attrs = attrs_at_byte (wbcg->edit_line.markup, target_pos_in_bytes);
-
-		for (ptr = attrs; ptr != NULL ; ptr = ptr->next) {
-			PangoAttribute *attr = ptr->data;
-			attr->start_index = 0;
-			attr->end_index = INT_MAX;
-			pango_attr_list_change (new_list, attr);
-		}
-		g_slist_free (attrs);
-		pango_attr_list_unref (wbcg->edit_line.cur_fmt);
-		wbcg->edit_line.cur_fmt = new_list;
-	}
+	set_cur_fmt (wbcg, target_pos_in_bytes);
 }
 
 typedef struct {
@@ -535,50 +561,47 @@ cb_entry_delete_text (GtkEditable    *editable,
 		      gint            end_pos,
 		      WorkbookControlGUI *wbcg)
 {
-	PangoAttrList *gunk;
-	EntryDeleteTextClosure change;
-	char const *str = gtk_entry_get_text (GTK_ENTRY (editable));
+	if (wbcg->auto_completing) {
+		wbcg_auto_complete_destroy (wbcg);
+		SCG_FOREACH_PANE (wbcg_cur_scg (wbcg), pane,
+			if (pane->editor != NULL)
+				foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
+	}
 
-	change.start_pos = g_utf8_offset_to_pointer (str, start_pos) - str;
-	change.end_pos   = g_utf8_offset_to_pointer (str, end_pos) - str;
-	change.len = change.end_pos - change.start_pos;
-	gunk = pango_attr_list_filter (wbcg->edit_line.full_content,
-		(PangoAttrFilterFunc) cb_delete_filter, &change);
-	if (gunk != NULL)
-		pango_attr_list_unref (gunk);
-	gunk = pango_attr_list_filter (wbcg->edit_line.markup,
-		(PangoAttrFilterFunc) cb_delete_filter, &change);
-	if (gunk != NULL)
-		pango_attr_list_unref (gunk);
-	cb_entry_cursor_pos (wbcg);
+	if (wbcg->edit_line.full_content) {
+		char const *str = gtk_entry_get_text (GTK_ENTRY (editable));
+		PangoAttrList *gunk;
+		EntryDeleteTextClosure change;
+
+		change.start_pos = g_utf8_offset_to_pointer (str, start_pos) - str;
+		change.end_pos   = g_utf8_offset_to_pointer (str, end_pos) - str;
+		change.len = change.end_pos - change.start_pos;
+		gunk = pango_attr_list_filter (wbcg->edit_line.full_content,
+					       (PangoAttrFilterFunc) cb_delete_filter, &change);
+		if (gunk != NULL)
+			pango_attr_list_unref (gunk);
+		gunk = pango_attr_list_filter (wbcg->edit_line.markup,
+					       (PangoAttrFilterFunc) cb_delete_filter, &change);
+		if (gunk != NULL)
+			pango_attr_list_unref (gunk);
+		cb_entry_cursor_pos (wbcg);
+	}
 }
 
 static void
 wbcg_edit_init_markup (WorkbookControlGUI *wbcg, PangoAttrList *markup)
 {
 	SheetView const *sv  = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
-	GObject *entry = (GObject *)wbcg_get_entry (wbcg);
+	const char *text = gtk_entry_get_text (wbcg_get_entry (wbcg));
 
 	g_return_if_fail (wbcg->edit_line.full_content == NULL);
 
 	wbcg->edit_line.markup = markup;
-	wbcg->edit_line.full_content = mstyle_generate_attrs_full (
+	wbcg->edit_line.full_content = gnm_style_generate_attrs_full (
 		sheet_style_get (sv->sheet, sv->edit_pos.col, sv->edit_pos.row));
 	pango_attr_list_splice (wbcg->edit_line.full_content, markup, 0, 0);
-	wbcg->edit_line.cur_fmt = pango_attr_list_copy (markup);
 
-	wbcg->edit_line.signal_insert = g_signal_connect (
-		entry, "insert-text",
-		G_CALLBACK (cb_entry_insert_text), wbcg);
-	wbcg->edit_line.signal_delete = g_signal_connect (
-		entry, "delete-text",
-		G_CALLBACK (cb_entry_delete_text), wbcg);
-	wbcg->edit_line.signal_cursor_pos = g_signal_connect_swapped (
-		entry, "notify::cursor-position",
-		G_CALLBACK (cb_entry_cursor_pos), wbcg);
-	wbcg->edit_line.signal_selection_bound = g_signal_connect_swapped (
-		entry, "notify::selection-bound",
-		G_CALLBACK (cb_entry_cursor_pos), wbcg);
+	set_cur_fmt (wbcg, strlen (text) - 1);
 }
 
 /**
@@ -680,7 +703,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	 * information if we look at the selection.
 	 */
 	if (wb_view_is_protected (wbv, TRUE) &&
-	    mstyle_get_content_locked (sheet_style_get (sv->sheet, col, row))) {
+	    gnm_style_get_content_locked (sheet_style_get (sv->sheet, col, row))) {
 		char *pos =  g_strdup_printf ( _("%s!%s is locked"),
 			sv->sheet->name_quoted, cell_coord_name (col, row));
 		go_cmd_context_error_invalid (GO_CMD_CONTEXT (wbcg), pos,
@@ -709,7 +732,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 
 		if (cell->value != NULL) {
 			GOFormat *fmt = VALUE_FMT (cell->value);
-			if (fmt != NULL && style_format_is_markup (fmt))
+			if (fmt != NULL && go_format_is_markup (fmt))
 				wbcg_edit_init_markup (wbcg,
 					pango_attr_list_copy (fmt->markup));
 		}
@@ -724,8 +747,8 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	/* Redraw the cell contents in case there was a span */
 	sheet_redraw_region (sv->sheet, col, row, col, row);
 
-	/* Activate auto-completion if this is not an expression */
-	if (wbv->do_auto_completion &&
+	if (cursorp && /* autocompletion code will not work in the edit line */
+	    wbv->do_auto_completion &&
 	    (text == NULL || g_unichar_isalpha (g_utf8_get_char (text)))) {
 		wbcg->auto_complete = complete_sheet_new (
 			sv->sheet, col, row,
@@ -736,14 +759,9 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 		wbcg->auto_complete = NULL;
 
 	/* Give the focus to the edit line */
-	if (!cursorp) {
-		GtkEntry *w = wbcg_get_entry (wbcg);
-		gtk_window_set_focus (GTK_WINDOW (wbcg->toplevel), GTK_WIDGET (w));
-		/* the gtk-entry-select-on-focus property of GtkEntry is not
-		 * what we want here.  Rather than trying some gtk-2.2 specific
-		 * magic just undo the selection change here */
-		gtk_editable_select_region (GTK_EDITABLE (w), -1, -1);
-	}
+	if (!cursorp)
+		gtk_window_set_focus (wbcg_toplevel (wbcg),
+			(GtkWidget *) wbcg_get_entry (wbcg));
 
 	wbcg->wb_control.editing = TRUE;
 	wbcg->wb_control.editing_sheet = sv->sheet;
@@ -756,10 +774,25 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	wbcg->edit_line.signal_changed = g_signal_connect (
 		G_OBJECT (wbcg_get_entry (wbcg)),
 		"changed",
-		G_CALLBACK (entry_changed), wbcg);
+		G_CALLBACK (cb_entry_changed), wbcg);
+	wbcg->edit_line.signal_insert = g_signal_connect (
+		G_OBJECT (wbcg_get_entry (wbcg)),
+		"insert-text",
+		G_CALLBACK (cb_entry_insert_text), wbcg);
+	wbcg->edit_line.signal_delete = g_signal_connect (
+		G_OBJECT (wbcg_get_entry (wbcg)),
+		"delete-text",
+		G_CALLBACK (cb_entry_delete_text), wbcg);
+	wbcg->edit_line.signal_cursor_pos = g_signal_connect_swapped (
+		G_OBJECT (wbcg_get_entry (wbcg)),
+		"notify::cursor-position",
+		G_CALLBACK (cb_entry_cursor_pos), wbcg);
+	wbcg->edit_line.signal_selection_bound = g_signal_connect_swapped (
+		G_OBJECT (wbcg_get_entry (wbcg)),
+		"notify::selection-bound",
+		G_CALLBACK (cb_entry_cursor_pos), wbcg);
 
-	if (text)
-		g_free (text);
+	g_free (text);
 	wb_control_update_action_sensitivity (WORKBOOK_CONTROL (wbcg));
 
 	inside_editing = FALSE;
@@ -899,46 +932,14 @@ wbcg_auto_completing (WorkbookControlGUI const *wbcg)
 static gboolean
 auto_complete_matches (WorkbookControlGUI *wbcg)
 {
-	GtkEntry *entry = wbcg_get_entry (wbcg);
-	int cursor_pos = gtk_editable_get_position (GTK_EDITABLE (entry));
-	char const *text = gtk_entry_get_text (entry);
-	gboolean equal;
-
-	/*
-	 * Ok, this sucks, ideally, I would like to do this test:
-	 * cursor_pos != strlen (text) to mean "user is editing,
-	 * hence, turn auto-complete off".
-	 *
-	 * But there is a complication: they way GtkEntry is implemented,
-	 * cursor_pos is not updated until after the text has been inserted
-	 * (this in turn emits the ::changed signal.
-	 *
-	 * So this is why it is so hairy and not really reliable.
-	 */
-	{
-		GdkEvent *event = gtk_get_current_event ();
-		gboolean perform_test = FALSE;
-
-		if (event && event->type != GDK_KEY_PRESS)
-			perform_test = TRUE;
-
-		if (perform_test)
-			if (cursor_pos != (int)g_utf8_strlen (text, -1))
-				wbcg->auto_completing = FALSE;
-
-		if (event)
-			gdk_event_free (event);
+	if (!wbcg->auto_completing || wbcg->auto_complete_text == NULL)
+		return FALSE;
+	else {
+		GtkEntry *entry = wbcg_get_entry (wbcg);
+		char const *text = gtk_entry_get_text (entry);
+		size_t len = strlen (text);
+		return strncmp (text, wbcg->auto_complete_text, len) == 0;
 	}
-
-	if (!wbcg->auto_completing)
-		return FALSE;
-
-	if (wbcg->auto_complete_text == NULL)
-		return FALSE;
-
-	equal = (strncmp (text, wbcg->auto_complete_text, strlen (text)) == 0);
-
-	return equal;
 }
 
 /*
